#
# spec file for package openstack-swift
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define component swift
%define groupname %{component}
%define username %{component}

%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif

%define version_unconverted 2.22.0.dev3

Name:           openstack-%{component}
Version:        2.22.0~dev3
Release:        1.1
Summary:        OpenStack Storage (Swift)
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://launchpad.net/swift
Source:         http://tarballs.openstack.org/swift/swift-master.tar.gz
Source2:        %{name}-account.service
Source3:        %{name}-account-auditor.service
Source4:        %{name}-account-reaper.service
Source5:        %{name}-account-replicator.service
Source6:        %{name}-container.service
Source7:        %{name}-container-auditor.service
Source8:        %{name}-container-replicator.service
Source9:        %{name}-container-updater.service
Source10:       %{name}-container-sync.service
Source11:       %{name}-object.service
Source12:       %{name}-object-replicator.service
Source13:       %{name}-object-expirer.service
Source14:       %{name}-object-updater.service
Source15:       %{name}-object-auditor.service
Source16:       %{name}-object-reconstructor.service
Source17:       %{name}-proxy.service
Source21:       test-configs-1.10.1.tar.bz2
Source22:       %{name}.logrotate
Source30:       %name.conf
BuildRequires:  systemd
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  crudini
BuildRequires:  fdupes
BuildRequires:  openstack-suse-macros
BuildRequires:  python-devel
BuildRequires:  python-pbr >= 0.5.21
Requires:       logrotate
Requires:       python >= 2.6.8
Requires:       python-swift = %{version}
Requires:       rsync
Requires(post): %insserv_prereq
%if 0%{?suse_version} > 1110
Requires(pre):  pwdutils
%else
Requires(pre):  shadow-utils
%endif
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
OpenStack Object Storage (swift) aggregates commodity servers to work
together in clusters for reliable, redundant, and large-scale storage
of static objects. Objects are written to multiple hardware devices in
the data center, with the OpenStack software responsible for ensuring
data replication and integrity across the cluster. Storage clusters can
scale horizontally by adding new nodes, which are automatically
configured. Should a node fail, OpenStack works to replicate its
content from other active nodes. Because OpenStack uses software logic
to ensure data replication and distribution across different devices,
inexpensive commodity hard drives and servers can be used in lieu of
more expensive equipment.

%package -n python-swift
Summary:        OpenStack Storage (Swift) - Python module
Group:          Development/Languages/Python
Requires:       python >= 2.6.8
Requires:       python-PasteDeploy >= 1.3.3
Requires:       python-PyECLib >= 1.3.1
Requires:       python-cryptography >= 1.8.2
Requires:       python-dnspython >= 1.14.0
Requires:       python-eventlet >= 0.17.4
Requires:       python-greenlet >= 0.3.1
Requires:       python-netifaces >= 0.8
Requires:       python-pbr >= 1.6
Requires:       python-simplejson >= 2.0.9
Requires:       python-six >= 1.9.0
Requires:       python-swiftclient >= 3.2.0
Requires:       python-xattr >= 0.4

%description -n python-swift
This package contains the core Python module of OpenStack Swift.

%package account
Summary:        OpenStack Storage (Swift) - Account Server
Group:          Productivity/Clustering/Computing
Requires:       %{name} = %{version}
Requires:       sqlite3 >= 3.6.23

%description account
OpenStack Object Storage (swift) aggregates commodity servers to work
together in clusters for reliable, redundant, and large-scale storage
of static objects.

This package contains the openstack-swift account server.

%package container
Summary:        OpenStack Storage (Swift) - Container Server
Group:          Productivity/Clustering/Computing
Requires:       %{name} = %{version}
Requires:       sqlite3 >= 3.6.23

%description container
OpenStack Object Storage (swift) aggregates commodity servers to work
together in clusters for reliable, redundant, and large-scale storage
of static objects.

This package contains the openstack-swift container server.

%package object
Summary:        OpenStack Storage (Swift) - Object Server
Group:          Productivity/Clustering/Computing
Requires:       %{name} = %{version}
Requires:       sqlite3 >= 3.6.23

%description object
OpenStack Object Storage (swift) aggregates commodity servers to work
together in clusters for reliable, redundant, and large-scale storage
of static objects.

This package contains the openstack-swift object server.

%package proxy
Summary:        OpenStack Storage (Swift) - Proxy Server
Group:          Productivity/Clustering/Computing
Requires:       %{name} = %{version}
Requires:       memcached

%description proxy
OpenStack Object Storage (swift) aggregates commodity servers to work
together in clusters for reliable, redundant, and large-scale storage
of static objects.

This package contains the openstack-swift proxy server.

%package test
Summary:        OpenStack Storage (Swift) - Testsuite
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       python-mock >= 2.0
Requires:       python-nose >= 1.3.7
Requires:       python-nosehtmloutput >= 0.0.3
Requires:       python-nosexcover >= 1.0.10
Requires:       python-openstack.nose_plugin

%description test
The OpenStack Swift testsuite. It is used to verify the functionality
of OpenStack Swift.

%prep
%setup -q -n %{component}-%{version_unconverted}
tar xvf %{SOURCE21}
%openstack_cleanup_prep

%build
python setup.py build

%install
python setup.py install --root %{buildroot} --prefix %{_prefix}

### directories
install -d -m 750 %{buildroot}%{_localstatedir}/cache/%{component}
install -d -m 750 %{buildroot}%{_localstatedir}/lib/%{component}
install -d -m 750 %{buildroot}%{_localstatedir}/log/%{component}
install -d -m 755 %{buildroot}%{_rundir}/swift
install -D -m 644 %{SOURCE30} %{buildroot}/%_tmpfilesdir/%name.conf

# systemd unit files
mkdir -p %{buildroot}%{_unitdir}
install -p -D -m 444 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}-account.service
install -p -D -m 444 %{SOURCE3} %{buildroot}%{_unitdir}/%{name}-account-auditor.service
install -p -D -m 444 %{SOURCE4} %{buildroot}%{_unitdir}/%{name}-account-reaper.service
install -p -D -m 444 %{SOURCE5} %{buildroot}%{_unitdir}/%{name}-account-replicator.service
install -p -D -m 444 %{SOURCE6} %{buildroot}%{_unitdir}/%{name}-container.service
install -p -D -m 444 %{SOURCE7} %{buildroot}%{_unitdir}/%{name}-container-auditor.service
install -p -D -m 444 %{SOURCE8} %{buildroot}%{_unitdir}/%{name}-container-replicator.service
install -p -D -m 444 %{SOURCE9} %{buildroot}%{_unitdir}/%{name}-container-updater.service
install -p -D -m 444 %{SOURCE10} %{buildroot}%{_unitdir}/%{name}-container-sync.service
install -p -D -m 444 %{SOURCE11} %{buildroot}%{_unitdir}/%{name}-object.service
install -p -D -m 444 %{SOURCE12} %{buildroot}%{_unitdir}/%{name}-object-replicator.service
install -p -D -m 444 %{SOURCE13} %{buildroot}%{_unitdir}/%{name}-object-expirer.service
install -p -D -m 444 %{SOURCE14} %{buildroot}%{_unitdir}/%{name}-object-updater.service
install -p -D -m 444 %{SOURCE15} %{buildroot}%{_unitdir}/%{name}-object-auditor.service
install -p -D -m 444 %{SOURCE16} %{buildroot}%{_unitdir}/%{name}-object-reconstructor.service
install -p -D -m 444 %{SOURCE17} %{buildroot}%{_unitdir}/%{name}-proxy.service
mkdir -p %{buildroot}%{_sbindir}
for server in account account-auditor account-reaper account-replicator container container-auditor container-replicator container-updater container-sync object object-replicator object-expirer object-updater object-auditor object-reconstructor proxy; do
    ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}-$server
done

# Install manpages
install -d %{buildroot}%{_mandir}/man{1,5}/
install -m 0644 doc/manpages/*.1 %{buildroot}%{_mandir}/man1/
install -m 0644 doc/manpages/*.5 %{buildroot}%{_mandir}/man5/

# Remove tests
rm -fr %{buildroot}/%{python_sitelib}/test

# Misc other
install -d -m 755 %{buildroot}%{_sysconfdir}/%{component}
for c in account-server container-server dispersion object-expirer object-server proxy-server swift; do
    install -m 644 etc/$c.conf-sample %{buildroot}%{_sysconfdir}/swift/$c.conf
done
for c in account-server container-server object-expirer object-server proxy-server ; do
    crudini --set %{buildroot}%{_sysconfdir}/swift/$c.conf DEFAULT user %{username}
done
crudini --set %{buildroot}%{_sysconfdir}/swift/dispersion.conf dispersion auth_user %{username}
# NOTE(saschpe): dispersion checks for localhost:8080/auth... by default...
crudini --set %{buildroot}%{_sysconfdir}/swift/proxy-server.conf DEFAULT bind_port 8080

install -p -D -m 644 %{SOURCE22} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

%fdupes %{buildroot}%{python_sitelib}/swift

# test sub-package
%openstack_test_package_install
pushd test-configs-*
  install -m 755 usr/bin/resetswift %{buildroot}%{_bindir}/resetswift
  install -m 755 usr/bin/remakerings %{buildroot}%{_bindir}/remakerings
popd
# those conflicts conflict with the real configs, need to find a different solution
#cp -r test-configs-*/* %{buildroot}/
# For ./.unittests:
install -m 0644 test/sample.conf %{buildroot}%{_sysconfdir}/swift/test.conf
# For ./.functests:
ln -s %{_sysconfdir}/swift/test.conf %{buildroot}%{_sysconfdir}/swift/func_test.conf

%pre
%openstack_pre_user_group_create %{username} %{groupname}

%post
%tmpfiles_create %{_tmpfilesdir}/%name.conf

%pre account
%service_add_pre %{name}-account.service

%post account
%service_add_post %{name}-account.service

%preun account
%service_del_preun %{name}-account.service

%postun account
%restart_on_update %{name}-account.service
%service_del_postun %{name}-account.service

%pre container
%service_add_pre %{name}-container.service

%post container
%service_add_post %{name}-container.service

%preun container
%service_del_preun %{name}-container.service

%postun container
%restart_on_update %{name}-container
%service_del_postun %{name}-container.service

%pre object
%service_add_pre %{name}-object.service

%post object
%service_add_post %{name}-object.service

%preun object
%service_del_preun %{name}-object.service

%postun object
%restart_on_update %{name}-object
%service_del_postun %{name}-object.service

%pre proxy
%service_add_pre %{name}-proxy.service

%post proxy
%service_add_post %{name}-proxy.service

%preun proxy
%service_del_preun %{name}-proxy.service

%postun proxy
%restart_on_update %{name}-proxy
%service_del_postun %{name}-proxy.service

%files
%defattr(-,root,root,-)
%doc README.rst
%_tmpfilesdir/%name.conf
%dir %attr(0750, %{username}, %{groupname}) %{_localstatedir}/log/%{component}
%dir %attr(0755, %{username}, %{groupname}) %{_sysconfdir}/%{component}
%dir %attr(0750, %{username}, %{groupname}) %{_localstatedir}/lib/swift
%dir %attr(0750, %{username}, %{groupname}) %{_localstatedir}/cache/swift
%{_bindir}/swift-account-audit
%{_bindir}/swift-dispersion-populate
%{_bindir}/swift-dispersion-report
%{_bindir}/swift-drive-audit
%{_bindir}/swift-form-signature
%{_bindir}/swift-get-nodes
%{_bindir}/swift-init
%{_bindir}/swift-config
%{_bindir}/swift-oldies
%{_bindir}/swift-orphans
%{_bindir}/swift-recon
%{_bindir}/swift-recon-cron
%{_bindir}/swift-ring-builder
%{_bindir}/swift-ring-builder-analyzer
%{_bindir}/swift-ring-composer
%{_bindir}/swift-manage-shard-ranges
%{_mandir}/man1/swift-account-audit.1.gz
%{_mandir}/man1/swift-config.1.gz
%{_mandir}/man1/swift-dispersion-populate.1.gz
%{_mandir}/man1/swift-dispersion-report.1.gz
%{_mandir}/man1/swift-drive-audit.1.gz
%{_mandir}/man1/swift-form-signature.1.gz
%{_mandir}/man1/swift-get-nodes.1.gz
%{_mandir}/man1/swift-oldies.1.gz
%{_mandir}/man1/swift-init.1.gz
%{_mandir}/man1/swift-orphans.1.gz
%{_mandir}/man1/swift-recon.1.gz
%{_mandir}/man1/swift-recon-cron.1.gz
%{_mandir}/man1/swift-ring-builder.1.gz
%{_mandir}/man1/swift-ring-builder-analyzer.1.gz
%{_mandir}/man1/swift-ring-composer.1.gz
%{_mandir}/man5/dispersion.conf.5.gz
%{_mandir}/man5/swift.conf.5.gz
%config(noreplace) %{_sysconfdir}/swift/swift.conf
%config(noreplace) %attr(0400, %{username}, %{groupname}) %{_sysconfdir}/swift/dispersion.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}

%files -n python-swift
%defattr(-,root,root,-)
%doc AUTHORS
%license LICENSE
%{python_sitelib}/swift
%{python_sitelib}/swift-2.*.egg-info

%files account
%defattr(-,root,root,-)
%{_unitdir}/%{name}-account*.service
%{_sbindir}/rc%{name}-account*
%config(noreplace) %{_sysconfdir}/swift/account-server.conf
%{_bindir}/swift-account-auditor
%{_bindir}/swift-account-info
%{_bindir}/swift-account-reaper
%{_bindir}/swift-account-replicator
%{_bindir}/swift-account-server
%{_mandir}/man1/swift-account-auditor.1.gz
%{_mandir}/man1/swift-account-info.1.gz
%{_mandir}/man1/swift-account-reaper.1.gz
%{_mandir}/man1/swift-account-replicator.1.gz
%{_mandir}/man1/swift-account-server.1.gz
%{_mandir}/man5/account-server.conf.5.gz

%files container
%defattr(-,root,root,-)
%{_unitdir}/%{name}-container*.service
%{_sbindir}/rc%{name}-container*
%config(noreplace) %{_sysconfdir}/swift/container-server.conf
%{_bindir}/swift-container-auditor
%{_bindir}/swift-container-reconciler
%{_bindir}/swift-container-info
%{_bindir}/swift-container-server
%{_bindir}/swift-container-replicator
%{_bindir}/swift-container-updater
%{_bindir}/swift-container-sync
%{_bindir}/swift-container-sharder
%{_bindir}/swift-reconciler-enqueue
%{_mandir}/man1/swift-container-auditor.1.gz
%{_mandir}/man1/swift-container-info.1.gz
%{_mandir}/man1/swift-container-server.1.gz
%{_mandir}/man1/swift-container-sync.1.gz
%{_mandir}/man1/swift-container-reconciler.1.gz
%{_mandir}/man1/swift-container-replicator.1.gz
%{_mandir}/man1/swift-container-updater.1.gz
%{_mandir}/man1/swift-reconciler-enqueue.1.gz
%{_mandir}/man5/container-server.conf.5.gz
%{_mandir}/man5/container-sync-realms.conf.5.gz
%{_mandir}/man5/container-reconciler.conf.5.gz

%files object
%defattr(-,root,root,-)
%doc etc/rsyncd.conf-sample
%{_unitdir}/%{name}-object*.service
%{_sbindir}/rc%{name}-object*
%config(noreplace) %{_sysconfdir}/swift/object-server.conf
%{_sysconfdir}/swift/object-expirer.conf
%{_bindir}/swift-object-auditor
%{_bindir}/swift-object-expirer
%{_bindir}/swift-object-info
%{_bindir}/swift-object-reconstructor
%{_bindir}/swift-object-replicator
%{_bindir}/swift-object-relinker
%{_bindir}/swift-object-server
%{_bindir}/swift-object-updater
%{_mandir}/man1/swift-object-auditor.1.gz
%{_mandir}/man1/swift-object-expirer.1.gz
%{_mandir}/man1/swift-object-info.1.gz
%{_mandir}/man1/swift-object-reconstructor.1.gz
%{_mandir}/man1/swift-object-replicator.1.gz
%{_mandir}/man1/swift-object-server.1.gz
%{_mandir}/man1/swift-object-updater.1.gz
%{_mandir}/man1/swift-object-relinker.1.gz
%{_mandir}/man5/object-expirer.conf.5.gz
%{_mandir}/man5/object-server.conf.5.gz

%files proxy
%defattr(-,root,root,-)
%{_unitdir}/%{name}-proxy.service
%{_sbindir}/rc%{name}-proxy
%config(noreplace) %{_sysconfdir}/swift/proxy-server.conf
%{_bindir}/swift-proxy-server
%{_mandir}/man1/swift-proxy-server.1.gz
%{_mandir}/man5/proxy-server.conf.5.gz

%files test
%defattr(-,root,root)
%dir %{_localstatedir}/lib/openstack-swift-test
%{_localstatedir}/lib/openstack-swift-test/*
%{_localstatedir}/lib/openstack-swift-test/.alltests
%{_localstatedir}/lib/openstack-swift-test/.functests
%{_localstatedir}/lib/openstack-swift-test/.probetests
%{_localstatedir}/lib/openstack-swift-test/.unittests
%{_localstatedir}/lib/openstack-swift-test/.testr.conf
%{_sysconfdir}/swift/test.conf
%{_sysconfdir}/swift/func_test.conf
%{_bindir}/remakerings
%{_bindir}/resetswift

%changelog
* Sat Mar 23 2019 cloud-devel@suse.de
- Update to version swift-2.20.1.dev157:
  swift (2.21.0, OpenStack Stein release)
  * Change the behavior of the EC reconstructor to perform a
    fragment rebuild to a handoff node when a primary peer responds
    with 507 to the REPLICATE request. This changes EC to match the
    existing behavior of replication when drives fail. After a
    rebalance of EC rings (potentially removing unmounted/failed
    devices), it's most IO efficient to run in handoffs_only mode to
    avoid unnecessary rebuilds.
  * O_TMPFILE support is now detected by attempting to use it
    instead of looking at the kernel version. This allows older
    kernels with backported patches to take advantage of the
    O_TMPFILE functionality.
  * Add slo_manifest_hook callback to allow other middlewares to
    impose additional constraints on or make edits to SLO manifests
    before being written. For example, a middleware could enforce
    minimum segment size or insert data segments.
  * Fixed an issue with multi-region EC policies that caused the EC
    reconstructor to constantly attempt cross-region rebuild
    traffic.
  * Fixed an issue where S3 API v4 signatures would not be validated
    against the body of the request, allowing a replay attack if
    request headers were captured by a malicious third party.
  * Display crypto data/metadata details in swift-object-info.
* Wed Feb 27 2019 cloud-devel@suse.de
- Update to version swift-2.20.1.dev102:
  2.19.1 (rocky stable backports)
  * Prevent PyKMIP's kmip_protocol logger from logging at DEBUG.
    Previously, some versions of PyKMIP would include all wire
    data when the root logger was configured to log at DEBUG; this
    could expose key material in logs. Only the kmip_keymaster was
    affected.
  * Fixed an issue where a failed drive could prevent the container sharder
    from making progress.
  * Fixed a bug in how Swift uses eventlet that was exposed under high
    concurrency.
  2.17.1 (queens stable backports)
  * Fix SLO delete for accounts with non-ASCII names.
  * Fixed an issue in COPY where concurrent requests may have copied the
    wrong data.
  * Fixed a bug in how Swift uses eventlet that was exposed under high
    concurrency.
  2.15.2 (pike stable backports)
  * Fixed a cache invalidation issue related to GET and PUT requests to
    containers that would occasionally cause object PUTs to a container to
    404 after the container had been successfully created.
  * Removed a race condition where a POST to an SLO could modify the
* Sat Dec 15 2018 cloud-devel@suse.de
- Update to version swift-2.19.1.dev244:
  swift (2.20.0)
  * S3 API compatibility updates
  * Swift can now cache the S3 secret from Keystone to use for
    subsequent requests. This functionality is disabled by default but
    can be enabled by setting the `secret_cache_duration` in the s3token
    section of the proxy server config to a number greater than 0.
  * s3api now mimics the AWS S3 behavior of periodically sending
    whitespace characters on a Complete Multipart Upload request to keep
    the connection from timing out. Note that since a request could fail
    after the initial 200 OK response has been sent, it is important to
    check the response body to determine if the request succeeded.
  * s3api now properly handles x-amz-metadata-directive headers on
    COPY operations.
  * s3api now uses concurrency (default 2) to handle multi-delete
    requests. This allows multi-delete requests to be processed much
    more quickly.
  * s3api now mimics some forms of AWS server-side encryption
    based on whether Swift's at-rest encryption functionality is enabled.
    Note that S3 API users are now able to know more about how the
    cluster is configured than they were previously, ie knowledge of
    encryption at-rest functionality being enabled or not.
  * s3api responses now include a '-' in multipart ETags.
* Wed Dec 12 2018 cdevita@suse.com
- set the permissions on dispersion.conf in openstack-swift.spec
  so that it is owned by swift:swift instead of root:root
  (bnc#1103759)
* Mon Nov 19 2018 sjamgade@suse.com
- change service depedancy from mysql.service to mariadb.service
* Tue Aug 28 2018 cloud-devel@suse.de
- Update to version swift-2.19.1.dev14:
  swift (2.19.0, OpenStack Rocky)
* Wed Aug 22 2018 cloud-devel@suse.de
- Update to version swift-2.18.1.dev229:
  swift (2.19.0)
  * TempURLs now support IP range restrictions. Please see
    https://docs.openstack.org/swift/latest/middleware.html#client-usage
    for more information on how to use this additional restriction.
  * Add support for multiple root encryption secrets for the trivial
    and KMIP keymasters. This allows operators to rotate encryption
    keys over time without needing to re-encrypt all existing data
    in the cluster. Please see the included sample config files for
    instructions on how to multiple encryption keys.
  * The object updater now supports two configuration settings:
    "concurrency" and "updater_workers". The latter controls how many
    worker processes are spawned, while the former controls how many
    concurrent container updates are performed by each worker
    process. This should speed the processing of async_pendings.
    On upgrade, a node configured with concurrency=N will still handle
    async updates N-at-a-time, but will do so using only one process
    instead of N.
    If you have a config file like this:
    [object-updater]
    concurrency = <N>
    and you want to take advantage of faster updates, then do this:
    [object-updater]
* Mon Aug 20 2018 comurphy@suse.com
- Fix license linter errors
* Mon Aug 20 2018 comurphy@suse.com
- Update to version swift-2.18.1.dev224:
  swift (2.18.0)
  * Added container sharding, an operator controlled feature that
    may be used to shard very large container databases into a
    number of smaller shard containers. This mitigates the issues
    with one large DB by distributing the data across multiple
    smaller databases throughout the cluster. Please read the full
    overview at
    https://docs.openstack.org/swift/latest/overview_container_sharding.html
  * Provide an S3 API compatibility layer. The external "swift3"
    project has been imported into Swift's codebase as the "s3api"
    middleware.
  * Added "emergency mode" hooks in the account and container replicators.
    These options may be used to prioritize moving handoff
    partitions to primary locations more quickly. This helps when
    adding capacity to a ring.
  - Added `-d <devs>` and `-p <partitions>` command line options.
  - Added a handoffs-only mode.
  * Add a multiprocess mode to the object replicator. Setting the
    "replicator_workers" setting to a positive value N will result
    in the replicator using up to N worker processes to perform
    replication tasks. At most one worker per disk will be spawned.
    Worker process logs will have a bit of information prepended so
    operators can tell which messages came from which worker. The
* Thu Apr  5 2018 tbechtold@suse.com
- Add missing Requires for python-six and python-cryptography
* Sat Feb  3 2018 cloud-devel@suse.de
- Update to version swift-2.16.1.dev191:
  swift (2.17.0)
  * Added symlink objects support.
    Symlink objects reference one other object. They are created by
    creating an empty object with an X-Symlink-Target header. The value of
    the header is of the format <container>/<object>, and the target does
    not need to exist at the time of symlink creation. Cross-account
    symlinks can be created by including the
    X-Symlink-Target-Account header.
    GET and HEAD requests to a symlink will operate on the
    referenced object and require appropriate permission in the
    target container. DELETE and PUT requests will operate on the
    symlink object itself. POST requests are not forwarded to the
    referenced object. POST requests sent to a symlink will result
    in a 307 Temporary Redirect response.
  * Added support for inline data segments in SLO manifests.
    Upgrade impact: during a rolling upgrade, an updated proxy server
    may write a manifest that an out-of-date proxy server will not be
    able to read. This will resolve itself once the upgrade completes
    on all nodes.
  * The tempurl digest algorithm is now configurable, and Swift added
    support for both SHA-256 and SHA-512. Supported tempurl digests
    are exposed to clients in `/info`. Additionally, tempurl signatures
    can now be base64 encoded.
* Tue Dec 12 2017 gosipyan@suse.com
- Remove `swift-temp-url` script The functionality exist in swiftclient
  Add container-sync-realms.conf.5.gz and container-reconciler.conf.5.gz
* Tue Dec 12 2017 gosipyan@suse.com 
- Update to version swift-2.16.1.dev21:
  swift (2.16.0)
  * Add checksum to object extended attributes.
  * Let clients request heartbeats during SLO PUTs by including
    the query parameter `heartbeat=on`.
    With heartbeating turned on, the proxy will start its response
    immediately with 202 Accepted then send a single whitespace
    character periodically until the request completes. At that
    point, a final summary chunk will be sent which includes a
    "Response Status" key indicating success or failure and (if
    successful) an "Etag" key indicating the Etag of the resulting
    SLO.
  * Added support for retrieving the encryption root secret from an
    external key management system. In practice, this is currently limited
    to Barbican.
  * Move listing formatting out to a new proxy middleware named
    `listing_formats`. `listing_formats` should be just right of the
    first proxy-logging middleware, and left of most other
    middlewares. If it is not already present, it will be
    automatically inserted for you.
    Note: if you have a custom middleware that makes account or
    container listings, it will only receive listings in JSON format.
  * Log deprecation warning for `allow_versions` in the container
    server config. Configure the `versioned_writes` middleware in
* Sat Sep 16 2017 cloud-devel@suse.de
- Update to version swift-2.15.2.dev57:
    https://docs.openstack.org/swift/latest/logs.html#swift-source for
    https://docs.openstack.org/swift/latest/overview_object_versioning.html.
    https://docs.openstack.org/swift/latest/admin_guide.html
    https://developer.openstack.org/api-ref/object-storage/.
    https://docs.openstack.org/swift/latest/overview_encryption.html.
    found at https://docs.openstack.org/swift/latest/ops_runbook/index.html and
    https://docs.openstack.org/swift/latest/overview_container_sync.html for more details
    https://docs.openstack.org/swift/latest/middleware.html#how-to-enable-object-versioning-in-a-swift-cluster
    Full docs are at https://docs.openstack.org/swift/latest/overview_erasure_code.html
    See https://docs.openstack.org/swift/latest/overview_auth.html for more details.
    swift_source. See https://docs.openstack.org/swift/latest/logs.html for details.
    See https://docs.openstack.org/swift/latest/overview_ring.html
    Please see https://docs.openstack.org/swift/latest/overview_auth.html for
    Full docs are at https://docs.openstack.org/swift/latest/overview_policies.html
    https://docs.openstack.org/swift/latest/overview_auth.html
    https://docs.openstack.org/swift/latest/overview_container_sync.html
    for full information.
    https://docs.openstack.org/swift/latest/crossdomain.html for details
    https://docs.openstack.org/swift/latest/apache_deployment_guide.html
    docs at https://docs.openstack.org/swift/latest/misc.html.
* Sat Aug 19 2017 cloud-devel@suse.de
- Update to version swift-2.15.1.dev43:
  swift (2.15.1)
  * Fixed a bug introduced in 2.15.0 where the object reconstructor
    would exit with a traceback if no EC policy was configured.
  * Fixed deadlock when logging from a tpool thread.
    The object server runs certain IO-intensive methods outside the
    main pthread for performance. Previously, if one of those methods
    tried to log, this can cause a crash that eventually leads to an
    object server with hundreds or thousands of greenthreads, all
    deadlocked. The fix is to use a mutex that works across different
    greenlets and different pthreads.
  * The object reconstructor can now rebuild an EC fragment for an
    expired object.
  * Various other minor bug fixes and improvements.
* Fri Jul 28 2017 cloud-devel@suse.de
- Update to version swift-2.14.1.dev183:
  swift (2.15.0)
  * Add Composite Ring Functionality
    A composite ring comprises two or more component rings that are
    combined to form a single ring with a replica count equal to the
    sum of the component rings. The component rings are built
    independently, using distinct devices in distinct regions, which
    means that the dispersion of replicas between the components can
    be guaranteed.
    Composite rings can be used for explicit replica placement and
    "replicated EC" for global erasure codes policies.
    Composite rings support 'cooperative' rebalance which means that
    during rebalance all component rings will be consulted before a
    partition is moved in any component ring. This avoids the same
    partition being simultaneously moved in multiple components.
    We do not yet have CLI tools for creating composite rings, but
    the functionality has been enabled in the ring modules to
    support this advanced functionality. CLI tools will be delivered
    in a subsequent release.
    For further information see the docs at
    <https://docs.openstack.org/swift/latest/overview_ring.html#module-swift.common.ring.composite_builder>
  * The EC reconstructor process has been dramatically improved by
    adding support for multiple concurrent workers. Multiple
    processes are required to get high concurrency, and this change
* Tue Jul 11 2017 tbechtold@suse.com
- update to 2.14.1~a0~dev139
* Thu Apr 27 2017 cloud-devel@suse.de
- Update to version swift-2.13.1.dev153:
  swift (2.14.0)
  * Fixed error where a container drive error resulted in double space
    usage on rest drives. When drive with container or account database
    is unmounted, the bug would create handoff replicas on all remaining
    drives, increasing the drive space used and filling the cluster.
  * Fixed UnicodeDecodeError in the object reconstructor that would
    prevent objects with non-ascii names from being reconstructed and
    caused the reconstructor process to hang.
  * EC Fragment Duplication - Foundational Global EC Cluster Support.
  * Fixed encoding issue in ssync where a mix of ascii and non-ascii
    metadata values would cause an error.
  * `name_check` and `cname_lookup` keys have been added to `/info`.
  * Add Vary: headers for CORS responses.
  * Always set Swift processes to use UTC.
  * Prevent logged traceback in object-server on client disconnect for
    chunked transfers to replicated policies.
  * Removed per-device reconstruction stats. Now that the reconstructor
    is shuffling parts before going through them, those stats no longer
    make sense.
  * Log correct status code for conditional requests.
* Thu Mar  9 2017 cloud-devel@suse.de
- Update to version swift-2.13.1.dev44:
    found at http://docs.openstack.org/developer/swift/ops_runbook/index.html and
    http://docs.openstack.org/developer/swift/overview_container_sync.html for more details
    http://docs.openstack.org/developer/swift/middleware.html#how-to-enable-object-versioning-in-a-swift-cluster
    Full docs are at http://docs.openstack.org/developer/swift/overview_erasure_code.html
    See http://docs.openstack.org/developer/swift/overview_auth.html for more details.
    swift_source. See http://docs.openstack.org/developer/swift/logs.html for details.
    Please see http://docs.openstack.org/developer/swift/overview_auth.html for
    Full docs are at http://docs.openstack.org/developer/swift/overview_policies.html
    http://docs.openstack.org/developer/swift/overview_auth.html
    http://docs.openstack.org/developer/swift/overview_container_sync.html for full
* Fri Feb 17 2017 cloud-devel@suse.de
- Update to version swift-2.12.1.dev107:
  swift (2.13.0, OpenStack Ocata)
  * Improvements in key parts of the consistency engine
  - Improved performance by eliminating an unneeded directory
    structure hash.
  - Optimized the common case for hashing filesystem trees, thus
    eliminating a lot of extraneous disk I/O.
  - Updated the `hashes.pkl` file format to include timestamp information
    for race detection. Also simplified hashing logic to prevent race
    conditions and optimize for the common case.
  - The erasure code reconstructor will now shuffle work jobs across all
    disks instead of going disk-by-disk. This eliminates single-disk I/O
    contention and allows continued scaling as concurrency is increased.
  - Erasure code reconstruction handles moving data from handoff nodes
    better. Instead of moving the data to another handoff, it waits
    until it can be moved to a primary node.
    Upgrade Impact: If you upgrade and roll back, you must delete all
    `hashes.pkl` files.
  * If using erasure coding with ISA-L in rs_vand mode and 5 or more parity
    fragments, Swift will emit a warning. This is a configuration that is
    known to harm data durability. In a future release, this warning will be
    upgraded to an error unless the policy is marked as deprecated. All data
    in an erasure code storage policy using isa_l_rs_vand with 5 or more
* Fri Feb  3 2017 tbechtold@suse.com
- Remove swift.conf.d/ dir. Swift does not use oslo.config so this
  does not work.
* Thu Dec 15 2016 aplanas@suse.com
- Create /etc/swift/swift.conf.d
* Thu Dec 15 2016 cloud-devel@suse.de
- Update to version swift-2.11.1.dev70:
  swift (2.12.0)
  * Ring files now include byteorder information about the endian of
    the machine used to generate the file, and the values are
    appropriately byteswapped if deserialized on a machine with a
    different endianness.
    Newly created ring files will be byteorder agnostic, but
    previously generated ring files will still fail on different
    endian architectures. Regenerating older ring files will cause
    them to become byteorder agnostic. The regeneration of the ring
    files will not cause any new data movement. Newer ring files
    will still be usable by older versions of Swift (on machines
    with the same endianness--this maintains existing behavior).
  * All 416 responses will now include a Content-Range header with
    an unsatisfied-range value. This allows the caller to know the
    valid range request value for an object.
  * TempURLs now support a validation against a common prefix. A
    prefix-based signature grants access to all objects which share the
    same prefix. This avoids the creation of a large amount of signatures,
    when a whole container or pseudofolder is shared.
  * Correctly handle deleted files with if-none-match requests.
  * Correctly send 412 Precondition Failed if a user sends an
    invalid copy destination. Previously Swift would send a 500
    Internal Server Error.
* Wed Dec  7 2016 aplanas@suse.com
- systemd: remove Wants from services.
* Tue Nov 29 2016 steven.kowalik@suse.com
- Switch to systemd service files.
  + Create /var/lib/swift
  + Remove shorter swift-container links, no longer needed since
    startproc is no longer used.
* Sat Nov 19 2016 cloud-devel@suse.de
- Update to version swift-2.11.1.dev5:
  swift (2.11.0)
  * We have made significant improvements and changes to the erasure
    code implementation.
  - Instead of using a separate .durable file to indicate the
    durable status of an EC fragment archive, we rename the .data
    to include a durable marker in the filename. This saves one
    inode for every EC .data file. Existing .durable files will not
    be removed, and they will continue to work just fine.
    Note that after writing EC data with Swift 2.11.0 or later, that
    data will not be accessible to earlier versions of Swift.
  - Closed a bug where ssync may have written bad fragment data in
    some circumstances. A check was added to ensure the correct number
    of bytes is written for a fragment before finalizing the write.
    Also, erasure coded fragment metadata will now be validated on read
    requests and, if bad data is found, the fragment will be quarantined.
  - The improvements to EC reads made in Swift 2.10.0 have also been
    applied to the reconstructor. This allows fragments to be rebuilt
    in more circumstances, resulting in faster recovery from failures.
  - WARNING: If you are using the ISA-L library for erasure codes,
    please upgrade to liberasurecode 1.3.1 (or later) as soon as
    possible. If you are using isa_l_rs_vand with more than 4 parity,
    please read https://bugs.launchpad.net/swift/+bug/1639691 and take
    necessary action.
* Sat Sep 24 2016 cloud-devel@suse.de
- Update to version swift-2.9.1.dev281:
  swift (2.10.0, OpenStack Newton)
  * Object versioning now supports a "history" mode in addition to
    the older "stack" mode. The difference is in how DELETE requests
    are handled. For full details, please read
    http://docs.openstack.org/developer/swift/overview_object_versioning.html.
  * New config variables to change the schedule priority and I/O
    scheduling class. Servers and daemons now understand
    `nice_priority`, `ionice_class`, and `ionice_priority` to
    schedule their relative importance. Please read
    http://docs.openstack.org/developer/swift/deployment_guide.html
    for full config details.
  * On newer kernels (3.15+ when using xfs), Swift will use the O_TMPFILE
    flag when opening a file instead of creating a temporary file
    and renaming it on commit. This makes the data path simpler and
    allows the filesystem to more efficiently optimize the files on
    disk, resulting in better performance.
  * Erasure code GET performance has been significantly
    improved in clusters that are not completely healthy.
  * Significant improvements to the api-ref doc available at
    http://developer.openstack.org/api-ref/object-storage/.
  * A PUT or POST to a container will now update the container's
    Last-Modified time, and that value will be included in a
    GET/HEAD response.
* Wed Sep 21 2016 mjura@suse.com
- Update to version 2.9.1.dev270
* Tue Sep  6 2016 tbechtold@suse.com
- Update to version 2.9.1.dev209
* Fri Aug 26 2016 aplanas@suse.com
- Revert generate PID file for systemd (bsc#991985)
* Mon Aug 22 2016 aplanas@suse.com
- Generate PID file for systemd (bsc#991985)
* Thu Jul 14 2016 cloud-devel@suse.de
- Update to version swift-2.8.1.dev93:
  swift (2.9.0)
  * Swift now supports at-rest encryption. This feature encrypts all
    object data and user-set object metadata as it is sent to the cluster.
    This feature is designed to prevent information leaks if a hard drive
    leaves the cluster. The encryption is transparent to the end-user.
    At-rest encryption in Swift is enabled on the proxy server by
    adding two middlewares to the pipeline. The `keymaster` middleware
    is responsible for managing the encryption keys and the `encryption`
    middleware does the actual encryption and decryption.
    Existing clusters will continue to work without enabling
    encryption. Although enabling this feature on existing clusters
    is supported, best practice is to enable this feature on new
    clusters when the cluster is created.
    For more information on the details of the at-rest encryption
    feature, please see the docs at
    http://docs.openstack.org/developer/swift/overview_encryption.html.
  * `swift-recon` can now be called with more than one server type.
  * Fixed a bug where non-ascii names could cause an error in logging
    and cause a 5xx response to the client.
  * The install guide and API reference have been moved into Swift's
    source code repository.
  * Various other minor bug fixes and improvements.
* Mon Jun 27 2016 jsuchome@suse.com
- Add systemd service macros (bnc#986415)
  systemd v228 has a separate generator for generating the service
  files from the init scripts, and daemon-reload is needed during
  package installation
* Tue Jun  7 2016 cloud-devel@suse.de
- Update to version swift-2.7.1.dev184:
  swift (2.8.0)
  * Allow concurrent bulk deletes for server-side deletes of static
    large objects. Previously this would be single-threaded and each
    DELETE executed serially. The new `delete_concurrency` value
    (default value is 2) in the `[filter:slo]` and `[filter:bulk]`
    sections of the proxy server config controls the concurrency
    used to perform the DELETE requests for referenced segments. The
    default value is recommended, but setting the value to 1
    restores previous behavior.
  * Refactor server-side copy as middleware
    The COPY verb is now implemented in the `copy` middleware instead
    of in the proxy server code. If not explicitly added, the server
    side copy middleware is auto-inserted to the left of `dlo`, `slo`
    and `versioned_writes` middlewares in the proxy server pipeline.
    As a result, dlo and slo `copy_hooks` are no longer required. SLO
    manifests are now validated when copied so when copying a
    manifest to another account the referenced segments must be
    readable in that account for the manifest copy to succeed
    (previously this validation was not made, meaning the manifest
    was copied but could be unusable if the segments were not
    readable).
    With this change, there should be no change in functionality or
    existing behavior.
  * `fallocate_reserve` can now be a percentage (a value ending in "%%"),
    and the default has been adjusted to "1%%".
* Tue Apr 19 2016 rhafer@suse.com
- Fix filelist, README.md was moved to README.rst
* Thu Mar 24 2016 cloud-devel@suse.de
- Update to version swift-2.6.1.dev262:
  swift (2.7.0, OpenStack Mitaka)
  * Bump PyECLib requirement to >= 1.2.0
  * Update container on fast-POST
    "Fast-POST" is the mode where `object_post_as_copy` is set to
    `False` in the proxy server config. This mode now allows for
    fast, efficient updates of metadata without needing to fully
    recopy the contents of the object. While the default still is
    `object_post_as_copy` as True, the plan is to change the default
    to False and then deprecate post-as-copy functionality in later
    releases. Fast-POST now supports container-sync functionality.
  * Add concurrent reads option to proxy.
    This change adds 2 new parameters to enable and control concurrent
    GETs in Swift, these are `concurrent_gets` and `concurrency_timeout`.
    `concurrent_gets` allows you to turn on or off concurrent
    GETs; when on, it will set the GET/HEAD concurrency to the
    replica count. And in the case of EC HEADs it will set it to
    ndata. The proxy will then serve only the first valid source to
    respond. This applies to all account, container, and replicated
    object GETs and HEADs. For EC only HEAD requests are affected.
    The default for `concurrent_gets` is off.
    `concurrency_timeout` is related to `concurrent_gets` and is
    the amount of time to wait before firing the next thread. A
    value of 0 will fire at the same time (fully concurrent), but
* Mon Feb 29 2016 johannes.grassler@suse.com
- Ensure swift services are started after openstack-keystone (bsc#955786)
* Fri Feb 26 2016 cloud-devel@suse.de
- Update to version swift-2.6.1.dev138:
  swift (2.6.0)
  * Dependency changes
  - Updated minimum version of eventlet to 0.17.4 to support IPv6.
  - Updated the minimum version of PyECLib to 1.0.7.
  * The ring rebalancing algorithm was updated to better handle edge cases
    and to give better (more balanced) rings in the general case. New rings
    will have better initial placement, capacity adjustments will move less
    data for better balance, and existing rings that were imbalanced should
    start to become better balanced as they go through rebalance cycles.
  * Added container and account reverse listings.
    A GET request to an account or container resource with a "reverse=true"
    query parameter will return the listing in reverse order. When
    iterating over pages of reverse listings, the relative order of marker
    and end_marker are swapped.
  * Storage policies now support having more than one name.
    This allows operators to fix a typo without breaking existing clients,
    or, alternatively, have "short names" for policies. This is implemented
    with the "aliases" config key in the storage policy config in
    swift.conf. The aliases value is a list of names that the storage
    policy may also be identified by. The storage policy "name" is used to
    report the policy to users (eg in container headers). The aliases have
    the same naming restrictions as the policy's primary name.
* Fri Jan 15 2016 vuntz@suse.com
- Fix init script for openstack-swift-object-expirer to reference
  object-expirer.conf, and not object-server.conf.
* Sun Oct  4 2015 cloud-devel@suse.de
- Update to version swift-2.4.1.dev70:
  swift (2.5.0, OpenStack Liberty)
  * Added the ability to specify ranges for Static Large Object (SLO)
    segments.
  * Replicator configs now support an "rsync_module" value to allow
    for per-device rsync modules. This setting gives operators the
    ability to fine-tune replication traffic in a Swift cluster and
    isolate replication disk IO to a particular device. Please see
    the docs and sample config files for more information and
    examples.
  * Significant work has gone in to testing, fixing, and validating
    Swift's erasure code support at different scales.
  * Swift now emits StatsD metrics on a per-policy basis.
  * Fixed an issue with Keystone integration where a COPY request to a
    service account may have succeeded even if a service token was not
    included in the request.
  * Ring validation now warns if a placement partition gets assigned to the
    same device multiple times. This happens when devices in the ring are
    unbalanced (e.g. two servers where one server has significantly more
    available capacity).
  * Various other minor bug fixes and improvements.
* Wed Sep  2 2015 cloud-devel@suse.de
- Update to version swift-2.3.1.dev356:
  swift (2.4.0)
  * Dependency changes
  - Added six requirement. This is part of an ongoing effort to add
    support for Python 3.
  - Dropped support for Python 2.6.
  * Config changes
  - Recent versions of Python restrict the number of headers allowed in a
    request to 100. This number may be too low for custom middleware. The
    new "extra_header_count" config value in swift.conf can be used to
    increase the number of headers allowed.
  - Renamed "run_pause" setting to "interval" (current configs with
    run_pause still work). Future versions of Swift may remove the
    run_pause setting.
  * Versioned writes middleware
    The versioned writes feature has been refactored and reimplemented as
    middleware. You should explicitly add the versioned_writes middleware to
    your proxy pipeline, but do not remove or disable the existing container
    server config setting ("allow_versions"), if it is currently enabled.
    The existing container server config setting enables existing
    containers to continue being versioned. Please see
    http://swift.openstack.org/middleware.html#how-to-enable-object-versioning-in-a-swift-cluster
    for further upgrade notes.
* Fri Aug 21 2015 cloud-devel@suse.de
- Update to version swift-2.3.1.dev307:
  swift (2.3.0, OpenStack Kilo)
  swift (2.2.0, OpenStack Juno)
  swift (1.13.1, OpenStack Icehouse)
  swift (1.10.0, OpenStack Havana)
  swift (1.8.0, OpenStack Grizzly)
  swift (1.7.4, OpenStack Folsom)
  swift (1.4.8, OpenStack Essex)
  swift (1.4.3, OpenStack Diablo)
  Changelog entries for previous versions are incomplete
  swift (1.3.0, OpenStack Cactus)
  swift (1.2.0, OpenStack Bexar)
  swift (1.0.0, OpenStack Austin)
* Thu Jul 23 2015 dmueller@suse.com
- add missing PyECLib requires
* Mon May  4 2015 vuntz@opensuse.org
- Update to version swift-2.3.1.dev12:
  swift (2.3.0)
  * Erasure Code support (beta)
    Swift now supports an erasure-code (EC) storage policy type. This allows
    deployers to achieve very high durability with less raw capacity as used
    in replicated storage. However, EC requires more CPU and network
    resources, so it is not good for every use case. EC is great for storing
    large, infrequently accessed data in a single region.
    Swift's implementation of erasure codes is meant to be transparent to
    end users. There is no API difference between replicated storage and
    EC storage.
    To support erasure codes, Swift now depends on PyECLib and
    liberasurecode. liberasurecode is a pluggable library that allows for
    the actual EC algorithm to be implemented in a library of your choosing.
    As a beta release, EC support is nearly fully feature complete, but it
    is lacking support for some features (like multi-range reads) and has
    not had a full performance characterization. This feature relies on
    ssync for durability. Deployers are urged to do extensive testing and
    not deploy production data using an erasure code storage policy.
    Full docs are at http://swift.openstack.org/overview_erasure_code.html
  * Add support for container TempURL Keys.
  * Make more memcache options configurable. connection_timeout,
    pool_timeout, tries, and io_timeout are all now configurable.
- Add init script for new object-reconstructor service.
* Fri Feb 13 2015 dmueller@suse.com
- update logrotate.conf
* Fri Jan 30 2015 cloud-devel@suse.de
- Update to version swift-2.2.2rc1.post9:
  swift (2.2.2)
  * Data placement changes
    This release has several major changes to data placement in Swift in
    order to better handle different deployment patterns. First, with an
    unbalance-able ring, less partitions will move if the movement doesn't
    result in any better dispersion across failure domains. Also, empty
    (partition weight of zero) devices will no longer keep partitions after
    rebalancing when there is an unbalance-able ring.
    Second, the notion of "overload" has been added to Swift's rings. This
    allows devices to take some extra partitions (more than would normally
    be allowed by the device weight) so that smaller and unbalanced clusters
    will have less data movement between servers, zones, or regions if there
    is a failure in the cluster.
    Finally, rings have a new metric called "dispersion". This is the
    percentage of partitions in the ring that have too many replicas in a
    particular failure domain. For example, if you have three servers in a
    cluster but two replicas for a partition get placed onto the same
    server, that partition will count towards the dispersion metric. A
    lower value is better, and the value can be used to find the proper
    value for "overload".
    The overload and dispersion metrics have been exposed in the
    swift-ring-build CLI tools.
    See http://docs.openstack.org/developer/swift/overview_ring.html
    for more info on how data placement works now.
* Tue Dec 16 2014 cloud-devel@suse.de
- Update to version swift-2.2.1c1.2.g8bbb50d:
  swift (2.2.1)
  * Swift now rejects object names with Unicode surrogates.
  * Return 403 (instead of 413) on unauthorized upload when over account
    quota.
  * Fix a rare condition when a rebalance could cause swift-ring-builder
    to crash. This would only happen on old ring files when "rebalance"
    was the first command run.
  * Storage node error limits now survive a ring reload.
  * Speed up reading and writing xattrs for object metadata by using larger
    xattr value sizes. The change is moving from 254 byte values to 64KiB
    values. There is no migration issue with this.
  * Deleted containers beyond the reclaim age are now properly reclaimed.
  * Full Simplified Chinese translation (zh_CN locale) for errors and logs.
  * Container quota is now properly enforced during cross-account COPY.
  * ssync replication now properly uses the configured replication_ip.
  * Fixed issue were ssync did not replicate custom object headers.
  * swift-drive-audit now has the 'unmount_failed_device' config option
    (default to True) that controls if the process will unmount failed
    drives or not.
* Wed Oct 15 2014 jsuchome@suse.cz
- logrotate fix: logs are not owned by swift user, but by root
* Sat Oct  4 2014 cloud-devel@suse.de
- Update to version swift-2.1.0.126.g94fd95b:
  swift (2.2.0)
  * Added support for Keystone v3 auth.
    Keystone v3 introduced the concept of "domains" and user names
    are no longer unique across domains. Swift's Keystone integration
    now requires that ACLs be set on IDs, which are unique across
    domains, and further restricts setting new ACLs to only use IDs.
    Please see http://swift.openstack.org/overview_auth.html for
    more information on configuring Swift and Keystone together.
  * Swift now supports server-side account-to-account copy. Server-
    side copy in Swift requires the X-Copy-From header (on a PUT)
    or the Destination header (on a COPY). To initiate an account-to-
    account copy, the existing header value remains the same, but the
    X-Copy-From-Account header (on a PUT) or the Destination-Account
    (on a COPY) are used to indicate the proper account.
  * Limit partition movement when adding a new placement tier.
    When adding a new placement tier (server, zone, or region), Swift
    previously attempted to move all placement partitions, regardless
    of the space available on the new tier, to ensure the best possible
    durability. Unfortunately, this could result in too many partitions
    being moved all at once to a new tier. Swift's ring-builder now
    ensures that only the correct number of placement partitions are
    rebalanced, and thus makes adding capacity to the cluster more
    efficient.
* Mon Aug 25 2014 bwiedemann@suse.com
- use %%_rundir if available, otherwise /var/run
* Sun Aug 24 2014 cloud-devel@suse.de
- Update to version swift-2.0.0.148.g8d02147:
  swift (2.1.0)
  * swift-ring-builder placement was improved to allow gradual addition
    of new regions without causing a massive migration of data to the new
    region. The change was to prefer device weight first, then look at
    failure domains.
  * Logging updates
  - Eliminated "Handoff requested (N)" log spam.
  - Added process pid to the end of storage node log lines.
  - Container auditor now logs a warning if the devices path contains a
    non-directory.
  - Object daemons now send a user-agent string with their full name.
  * 412 and 416 responses are no longer tracked as errors in the StatsD
    messages from the backend servers.
  * Parallel object auditor
    The object auditor can now be controlled with a "concurrency" config
    value that allows multiple auditor processes to run at once. Using
    multiple parallel auditor processes can speed up the overall auditor
    cycle time.
  * The object updater will now concurrently update each necessary node
    in a new greenthread.
* Wed Aug 13 2014 aspiers@suse.com
- Fix crash of swift-proxy-server when started via Pacemaker
  (bnc#887305)
* Fri Jun 27 2014 dmueller@suse.com
- Update to version swift-2.0.0.rc1.12.g53577c5:
  swift (2.0.0)
  * Storage policies
    Storage policies allow deployers to configure multiple object rings
    and expose them to end users on a per-container basis. Deployers
    can create policies based on hardware performance, regions, or other
    criteria and independently choose different replication factors on
    them. A policy is set on a Swift container at container creation
    time and cannot be changed.
    Full docs are at http://swift.openstack.org/overview_policies.html
  * Add profiling middleware in Swift
    The profile middleware provides a tool to profile Swift
    code on the fly and collects statistical data for performance
    analysis. A native simple Web UI is also provided to help
    query and visualize the data.
  * Add --quoted option to swift-temp-url
  * swift-recon now supports checking the md5sum of swift.conf, which
    helps deployers verify configurations are consistent across a cluster.
  * Users can now set the transaction id suffix by passing in
    a value in the X-Trans-Id-Extra header.
  * New log_max_line_length option caps the maximum length of a log line.
* Fri Jun 20 2014 jsuchome@suse.cz
- added log directory and logrotate configuration (bnc#879931)
* Fri Apr  4 2014 cloud-devel@suse.de
- Update to version swift-1.13.0.116.gbf292ae:
  swift (1.13.1)
  * Change the behavior of CORS responses to better match the spec
    A new proxy config variable (strict_cors_mode, default to True)
    has been added. Setting it to False keeps the old behavior. For
    an overview of old versus new behavior, please see
    https://review.openstack.org/#/c/69419/
  * Invert the responsibility of the two instances of proxy-logging in
    the proxy pipeline
    The first proxy_logging middleware instance to receive a request
    in the pipeline marks that request as handling it. So now, the
    left most proxy_logging middleware handles logging for all
    client requests, and the right most proxy_logging middleware
    handles all other requests initiated from within the pipeline to
    its left. This fixes logging related to large object
    requests not properly recording bandwidth.
  * Added swift-container-info and swift-account-info tools
  * Allow specification of object devices for audit
  * Dynamic large object COPY requests with ?multipart-manifest=get
    now work as expected
  * When a client is downloading a large object and one of the segment
    reads gets bad data, Swift will now immediately abort the request.
* Tue Apr  1 2014 cloud-devel@suse.de
- Update to version swift-1.13.0.91.g917cf9e:
    replication. Can also configure how many remote nodes a storage node
* Sat Mar 22 2014 cloud-devel@suse.de
- Update to version 1.10.1:
  + The openstack-swift service user is going to be renamed to swift
* Mon Mar 17 2014 rhafer@suse.com
- switch over to non-openstack-prefix'ed users
* Fri Mar  7 2014 speilicke@suse.com
- Add python_requires source service
- Cleanup requirements
* Tue Feb 25 2014 cloud-devel@suse.de
- Update to version swift-1.12.0.111.g58fda94:
  swift (1.13.0)
  * Account-level ACLs and ACL format v2
    Accounts now have a new privileged header to represent ACLs or
    any other form of account-level access control. The value of
    the header is a JSON dictionary string to be interpreted by the
    auth system. A reference implementation is given in TempAuth.
    Please see the full docs at
    http://swift.openstack.org/overview_auth.html
  * Added a WSGI environment flag to stop swob from always using
    absolute location. This is useful if middleware needs to use
    out-of-spec Location headers in a response.
  * Container sync proxies now support simple load balancing
  * Config option to lower the timeout for recoverable object GETs
  * Add a way to ratelimit all writes to an account
  * Allow multiple storage_domain values in cname_lookup middleware
  * Moved all DLO functionality into middleware
    The proxy will automatically insert the dlo middleware at an
    appropriate place in the pipeline the same way it does with the
    gatekeeper middleware. Clusters will still support DLOs after upgrade
    even with an old config file that doesn't mention dlo at all.
* Thu Feb 13 2014 speilicke@suse.com
- Replace git_tarballs source service with download_files and set_version
  + Use upstream URL as source (enables verification)
- Rename swift-test-configs to test-configs so that the basename doesn't
  colide with swift-master.tar.gz (that would confuse set_version)
* Thu Feb 13 2014 dmueller@suse.com
- remove d2to1 dependency
* Wed Feb 12 2014 dmueller@suse.com
- directory permission cleanup
* Wed Feb 12 2014 opensuse-cloud@opensuse.org
- Update to version 1.12.0.68.g8902aef+git.1392166281.8902aef:
  + Remove swiftclient dependency
* Tue Feb 11 2014 opensuse-cloud@opensuse.org
- Update to version 1.12.0.66.g8fdb321+git.1392081427.8fdb321:
  + Attempt to make test_memcache_pool_timeout stable
  + Fix recon docs
* Sat Feb  8 2014 opensuse-cloud@opensuse.org
- Update to version 1.12.0.63.g9e9c095+git.1391820115.9e9c095:
  + Add tests for swift-ring-builder
  + Fix a comment in SLO middleware
* Fri Feb  7 2014 opensuse-cloud@opensuse.org
- Update to version 1.12.0.60.g00472e8+git.1391736054.00472e8:
  + Fix a couple ifs in account quota middleware.
  + Make .expiring_objects account name configurable
  + Fix a comment in bulk middleware.
* Thu Feb  6 2014 opensuse-cloud@opensuse.org
- Update to version 1.12.0.54.g6fec0dd+git.1391647320.6fec0dd:
  + Move all DLO functionality to middleware
* Wed Feb  5 2014 opensuse-cloud@opensuse.org
- Update to version 1.12.0.52.gb1cacf4+git.1391599838.b1cacf4:
  + Sanify handoff search depth with non-integer replica counts
  + Documentation of the logs formats used in Swift
  + Fix container quota MW for handling a bad source path
  + Let swift-object-info skip etag verification
  + Add missing sample config of object-replicator
  + Add some tests for bin/swift-recon
  + Fix up double mocking of swob.Request.__init__
  + Fix numbering of steps in proxy section of install_multinode
* Wed Feb  5 2014 speilicke@suse.com
- Fix ghosting /var/run on 12.3
* Tue Feb  4 2014 opensuse-cloud@opensuse.org
- Update to version 1.12.0.36.g7e2f9bb+git.1391474286.7e2f9bb:
  + Privileged acct ACL header, new ACL syntax, TempAuth impl.
  + Reduce line count by two
* Sun Feb  2 2014 opensuse-cloud@opensuse.org
- Update to version 1.12.0.32.ge16ea69+git.1391302272.e16ea69:
  + Remove dependencies on pep8, pyflakes and flake8
  + Attempt to fix periodic memcache timeout test
* Sat Feb  1 2014 opensuse-cloud@opensuse.org
- Update to version 1.12.0.28.g92e3478+git.1391219098.92e3478:
  + Container Sync: Simple HTTP Proxy load balancing
  + Add a way to ratelimit all writes to an account
* Fri Jan 31 2014 opensuse-cloud@opensuse.org
- Update to version 1.12.0.24.g6b8f845+git.1391129530.6b8f845:
  + Some functional tests for object versioning
  + Make swift-recon usable on hosts without IPv6
  + Skip delete_at_update for replication requests
  + Config option to lower the timeout for recoverable object GETs.
* Thu Jan 30 2014 dmueller@suse.com
- move lock_path to /var/run
* Thu Jan 30 2014 opensuse-cloud@opensuse.org
- Update to version 1.12.0.16.gb202789+git.1391044049.b202789:
  + Add flag to stop swob from always using absolute location.
* Wed Jan 29 2014 vuntz@suse.com
- Use correct group name for directory ownerships.
- Do not make /var/{lock,run}/swift readable by others.
* Tue Jan 28 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.136.g9034558+git.1390873550.9034558:
  + Add secondary groups to user during privilege escalation
* Mon Jan 27 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.134.g61f9380+git.1390784237.61f9380:
  + Move test.unit.locale out of gettext's way
* Sun Jan 26 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.132.g89deaf5+git.1390696935.89deaf5:
  + Add flag to stop swob from always using absolute location.
* Sat Jan 25 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.131.g9b3c86f+git.1390610447.9b3c86f:
  + ismount should not raise exceptions
  + Use a tempfile.mkdtemp() based temporary directory
  + Add debug logger on per-test proxy-server
  + Add documentation for GateKeeper
* Fri Jan 24 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.123.g6310491+git.1390569082.6310491:
  + Adjust unit tests to clarify existing device usage
  + release notes and authors update for 1.12
  + Fix up SAIO to use new gatekeeper
* Wed Jan 22 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.109.g8eabb13+git.1390351276.7fead41:
  + Make test_close_error run much faster
  + Fix swift-dispersion-report when partitions overlap
  + Make sure SLO's bulk-delete logger is configured
  + lower the default yield frequency for bulk requests
* Mon Jan 20 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.109.g8eabb13+git.1390179193.8eabb13:
  + Mute hash_suffix rmdir failures
  + Mute hash_cleanup_listdir common failures
  + Fix Error 400 Header Line Too Long
  + Drop origin from get_info calls
* Sun Jan 19 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.99.gf3382a2+git.1390095248.b5697c8:
  + Remove an useless dependency to swiftclient
  + Use constant-time string compare for /info requests
* Sat Jan 18 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.97.gddb937c+git.1390009391.ddb937c:
  + Consolidating and standardizing x-delete-at format
  + Use constant time comparison in tempURL
* Fri Jan 17 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.93.gd68fbfc+git.1389919366.d68fbfc:
  + use specific hacking rules
  + Expose some SLO constraints via /info
* Thu Jan 16 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.89.g233f539+git.1389836396.233f539:
  + Add missing setting to SLO sample conf
* Wed Jan 15 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.87.gd698c21+git.1389748870.d698c21:
  + New container sync configuration option
* Tue Jan 14 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.85.g356282e+git.1389663002.356282e:
  + Warn if read_affinity is configured but not enabled
  + Move all SLO functionality to middleware
* Mon Jan 13 2014 vuntz@suse.com
- Fix group ownership added in previous change.
* Mon Jan 13 2014 jsuchome@suse.cz
- set directories onwership (/etc/swift, /var/lock/swift,
  /var/cache/swift) in the package (bnc#858194)
* Mon Jan 13 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.81.g8b40f19+git.1389576633.8b40f19:
  + Make POST for bulk delete actually work
  + Update account quota doc
  + Allow programmatic reloading of Swift hash path config
* Sun Jan 12 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.75.g685f9a8+git.1389487095.685f9a8:
  + Log when quarantining an object
  + Add missing license header to test file
* Sat Jan 11 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.71.gf310006+git.1389404660.f310006:
  + Various optimizations to RingBuilder.rebalance()
  + Generic means for persisting system metadata.
* Fri Jan 10 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.67.g18cb1de+git.1389354100.18cb1de:
  + Refactor to share on-disk layout with hash cleanup
  + Move the tests from functionalnosetests
  + Add Swift-account-stats as a related project.
  + Raise diskfile.py module coverage to > 98%%
* Thu Jan  9 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.57.g0d28cd2+git.1389231109.c709cf9:
  + Adds a retry mechanism when deleting containers
  + Remove trailing slash for consistency
* Wed Jan  8 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.55.gdb63240+git.1389144371.db63240:
  + Remove swiftclient dep on direct_client
  + Don't report async pendings on exception
  + Whitelist external netifaces requirement
* Fri Jan  3 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.50.gcd378ed+git.1388710102.cd378ed:
  + Fix checkmount  error parsing in swift-recon
* Thu Jan  2 2014 opensuse-cloud@opensuse.org
- Update to version 1.11.0.48.gb9dd7c7+git.1388686979.b9dd7c7:
  + Preserve tracebacks from run_in_thread
  + Allow specify arguments to .probetests script
  + Up nproc limit on startup.
* Thu Dec 26 2013 opensuse-cloud@opensuse.org
- Update to version 1.11.0.42.gda26219+git.1388018556.da26219:
  + Add swiftbrowser as an associated project
* Tue Dec 24 2013 opensuse-cloud@opensuse.org
- Update to version 1.11.0.40.gdfb5dea+git.1387846810.dfb5dea:
  + Expose allowed tempurl methods in /info
  + Allow running just one test with tox
  + test 3 date format in functional tests
* Sat Dec 21 2013 opensuse-cloud@opensuse.org
- Update to version 1.11.0.34.gafe794e+git.1387589391.afe794e:
  + Force catch_errors into pipeline
* Fri Dec 20 2013 opensuse-cloud@opensuse.org
- Update to version 1.11.0.32.g7f456ef+git.1387503130.7f456ef:
  + Make ssync_receiver drop conn on exc
  + Fix obj versioning w/non-ASCII container name
  + change the last-modified header value with valid one
* Wed Dec 18 2013 opensuse-cloud@opensuse.org
- Update to version 1.11.0.27.g3c82cfc+git.1387329177.3c82cfc:
  + Just trying to keep /tmp clean
  + update ssync tests to use req.get_response()
* Tue Dec 17 2013 opensuse-cloud@opensuse.org
- Update to version 1.11.0.24.g1bb6563+git.1387241923.1bb6563:
  + Handle non-integer values for if-delete-at
* Sun Dec 15 2013 opensuse-cloud@opensuse.org
- Update to version 1.11.0.23.gf3f437f+git.1387068666.f3f437f:
  + Remove start index 0 in range()
  + Sync global requirements to pin sphinx to sphinx>=1.1.2,<1.2
  + Updates tox.ini to use new features
  + Bring obj server unit tests to > 98%%
  + Expose basic constraints in /info
  + Only retry GETs for objects.
  + Update swift-config paste appconfig inspection
* Sat Dec 14 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.206.g4dfe31e+git.1386982909.4dfe31e:
  + Return an exit code for configuration errors
  + Add some tests to demonstrate hash_cleanup_listdir
* Thu Dec 12 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.203.gc8c512b+git.1386811711.c8c512b:
  + Increases the UT coverage of db_replicator.py
  + Use /info to check if SLO is enabled
* Wed Dec 11 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.199.g9a2bd79+git.1386724786.9a2bd79:
  + Sync global requirements to pin sphinx to sphinx>=1.1.2,<1.2
* Tue Dec 10 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.198.gba5fe5f+git.1386670195.ba5fe5f:
  + Prevent early auth deny in tempauth when using swift3 middleware.
  + Remove swift-bench
  + Update handoff algorithm to use IP/port pairs
  + Preserve closeability of app iterables
  + Opt out of the service catalog
  + fix expired object deletion
  + Allow access to the in-memory object server
  + Fixed a failing test on my saio
  + Override spelling of tempauth test name
  + Fix HEAD tempurls
  + Release notes for Swift 1.11.0
  + Stop mutating PATH_INFO in proxy server
  + make test tooling less opinionated
  + clarify the current state of the DiskFile API
  + Use files in the source tree instead of cut/paste
* Thu Dec  5 2013 speilicke@suse.com
- Update swift-test-configs to version 1.10.0:
  + Inital commitReplace resetswift script with proper version
  + Drop README
  + Make sure mount point exists
  + Point to correct storage directory in configuration files
  + Add missing object-expirer.conf
  + Use variable
- Update to version 1.10.0.170.g30c0c08+git.1386258460.30c0c08:
  + Add accurate timestamps in proxy log
  + Expose bulk-operation limits in /info.
  + Some functional tests for dynamic large objects
  + GreenDBConnection no longer assumes that arguments are kwargs
  + Fixed DB test cases on PyPy
  + Add option to return disk usage report with byte suffix.
  + Remove ssync iter_hook usage
  + use diskfile in ssync_sender tests
- Refreshed dependencies
* Tue Dec  3 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.154.gbdcf6ad+git.1386033255.bdcf6ad:
  + Remove Python 3.3 from list of tox environments
* Fri Nov 29 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.153.g73b0df1+git.1385686330.73b0df1:
  + in case you lose your builder backups
  + workaround probetest race from early response
  + Protect against hash cleanup errors on PUTs
  + Report transaction ID in failure exceptions
* Thu Nov 28 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.145.g6cd32eb+git.1385601030.6cd32eb:
  + Some functional tests for static large objects
  + Reorganize SLO unit tests
  + test: improve db_replicator coverage
  + Added discoverable capabilities.
  + slightly less early quorum
  + Remove unnecessary "is not None" check
  + Push cooperative sleep call down into ThreadPool
  + bare excepts, as is proper
  + Report path information in failure exceptions
  + Fix bug in obj updater run_once().
  + Add HTML reporting for test branch coverage.
  + Use TCP_NODELAY for created sockets.
  + Account for a platform difference in semaphores
  + Add a unit test to verify proxy logging fields
* Wed Nov 27 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.118.g2ce0e62+git.1385513096.2ce0e62:
  + allow bare excepts in flake8
  + Add a DebugLogger for wsgi server tests
  + Use upstream patched Pool.get
  + Fix for memcache middleware configuration
  + add bare except to catch errors
* Mon Nov 25 2013 dmueller@suse.com
- switch to python-setuptools
* Mon Nov 25 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.109.g91deed8+git.1385343197.91deed8:
  + Use a more portable errno in tests.
* Sat Nov 23 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.108.g5989849+git.1385168012.5989849:
  + Fix quarantine, error counts in audit logs
  + Fix test to work with mock 0.8.0
  + Fix UnboundLocalError on container PUT
  + Use POST in bulk-delete
  + Import filter and app into namespace correctly
  + Fix DB locked error on commit
  + Fixed locale test in the presence of LANGUAGE
  + Do not format messages before they are logged
  + add an "inline" query parameter to tempurl
  + Handle optional arguments for run_forever()
  + Simple fix for proxy-logging empty field handling
  + Remove obsolete future imports
  + Get retry.
  + Per device replication_lock
* Fri Nov 22 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.81.g1508534+git.1385080716.1508534:
  + Handle COPY verb in account quota middleware
  + improve docs in etc/dispersion.conf-sample
  + Fix probe test
  + minor fix to unittest fake error
  + Use utils.ismount in place of os.path.ismount
  + Replace httplib with bufferedhttp in sphinx docs
* Thu Nov 21 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.69.g9081b33+git.1384996529.9081b33:
  + Quiet all locale warnings and dummy thread, too
  + Fixed concurrent PUT requests to accounts or containers
* Sat Nov 16 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.66.g8255810+git.1384563848.8255810:
  + Add swiftsync.
* Thu Nov 14 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.65.gfd4843f+git.1384390335.fd4843f:
  + Remove some WebOb leftovers.
  + catch OSError to prevent breaking request /recon/diskusage
* Wed Nov 13 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.62.gaf2f829+git.1384303734.af2f829:
  + Add more stuff to SAIO doc's proxy pipeline.
* Sun Nov 10 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.60.g41e1a53+git.1384047879.41e1a53:
  + Fix up sphinx docs for *make_request* methods
* Sat Nov  9 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.58.g6152391+git.1383959728.6152391:
  + Default region loading an old-style pickled ring
  + Remove redundant hash check
* Fri Nov  8 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.55.gc8b6bc7+git.1383871338.c8b6bc7:
  + HEAD on account returns 410 if account was deleted and not yet reaped
  + early quorum responses
  + Object replication ssync (an rsync alternative)
* Thu Nov  7 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.49.gdeaddf0+git.1383786084.deaddf0:
  + Alternate DiskFile constructor for efficient auditing.
* Wed Nov  6 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.47.g429cb8b+git.1383699997.429cb8b:
  + Fix swift_test_client duplicating request params
* Tue Nov  5 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.46.gf63b58f+git.1383612309.f63b58f:
  + Add colon after service name
  + Fix deprecation warning.
* Fri Nov  1 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.43.g84f494c+git.1383269456.84f494c:
  + Tie socket write buffer size to server parameters
  + Remove unnecessary swift_conn comments
* Thu Oct 31 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.39.g02f7e78+git.1383183171.02f7e78:
  + form post over XMLHttpRequest (cors) broken
  + Make pbr a build-time only dependency
  + Quarantine objects with busted metadata.
  + Strengthen account tests
* Sun Oct 27 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.33.g4bfe674+git.1382839159.4bfe674:
  + Fix UnboundLocalError on account PUT
  + Simplify callers of diskfile.[read|write]_metadata()
  + Update my mailmap
  + catch decompression errors
* Thu Oct 24 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.24.gabcecd2+git.1382572988.7ccde73:
  + Add an __str__ method to brokers
  + utf8 encode tempurl key
* Tue Oct 22 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.23.gd7dcb48+git.1382484781.d7dcb48:
  + Faster swift-dispersion-populate
  + Adding more unit tests for audit_location_generator
  + Add WWW-Authenticate to 401 responses
* Tue Oct 22 2013 speilicke@suse.com
- Update to version 1.10.0.17.g0c6764b+git.1382455353.0c6764b:
  + Make test_translations test our tree
  + Small efficiency improvement in account quotas
- Fix swift-test-config version number in _service to match current
  swift release
- Better default config, set auth_user for dispersion and bind_port for
  proxy-server. "user" isn't used in /etc/swift/swift.conf
* Mon Oct 21 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.13.g16ddd3c+git.1382399936.16ddd3c:
  + Proxy: use just one greenthread per client
* Fri Oct 18 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.11.g79e2a50+git.1382055752.79e2a50:
  + Small optimization to container_quotas
  + DiskFile API, with reference implementation
* Thu Oct 17 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.rc1.7.g2b639f5+git.1381968720.2b639f5:
  + Fix 500 from account-quota middleware
* Wed Oct 16 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.rc1.5.gb804c72+git.1381882895.b804c72:
  + return value on memcache client decr call
  + Removes vim comment
* Mon Oct 14 2013 opensuse-cloud@opensuse.org
- Update to version 1.10.0.rc1.2.g5964082+git.1381752538.5964082:
  + Handle X-Copy-From header in container_quota middleware
  + Fix utf-8 handling in object versions.
  + Revert "Refactor common/utils methods to common/ondisk"
  + Don't apply timeout to Pool.get operation (leaks)
  + Add a Timeout when getting Memcache connections
  + allow container create even if over account quota
  + CHANGELOG and AUTHORS updates for 1.10.0 release
* Wed Oct  9 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.213.g55d0eb6+git.1381278683.55d0eb6:
  + Two small account-quota fixes
* Tue Oct  8 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.211.g841b808+git.1381234982.841b808:
  + Fix default replication options for ring-builder add
  + Change OpenStack LLC to Foundation
  + Set path_info in sub_slo manifest GET requests
  + Simplify object path when reporting SLO put errors
  + Fedora 19 updates
  + Pool memcache connections
  + Allow slightly older dnspython (>= 1.9.4).
  + Add "note" box callouts to SAIO for user changes.
  + assertEquals is deprecated, use assertEqual
  + Stop reading from object server when client disconnects.
  + Remove sphinx build warnings
  + Fedora 19: need to use /etc/rc.d/rc.local
  + Fix bad hash_path reference
  + Correct URL in readme
* Tue Oct  1 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.186.gfe69cab+git.1380671599.c7a9cb9:
  + Use created container in unit test
  + Move location of HTTPException in swift_testing
* Tue Oct  1 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.180.g5eea524+git.1380587981.5eea524:
  + bulk delete bug with trailing whitespace
* Sun Sep 29 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.178.g9befc70+git.1380415343.9befc70:
  + Install libffi-dev in SAIO docs.
  + improve bulk document
* Fri Sep 27 2013 dmueller@suse.com
- switch to crudini
* Thu Sep 26 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.175.gc1f9f66+git.1380213982.c1f9f66:
  + update SLO delete error handling
  + Update SAIO doc to have double proxy-logging in pipeline.
  + Fix internal swift.source tracking.
* Wed Sep 25 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.170.gbb3f965+git.1380067212.bb3f965:
  + Log x-copy-from when it could be useful
* Sat Sep 21 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.168.g10bb74a+git.1379722790.10bb74a:
  + Add a user variable to templates
  + SLOs broken for range requests
  + Fix unsuitable assertTrue
* Fri Sep 20 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.163.g9ca7085+git.1379637275.9ca7085:
  + Fix probe tests
  + add seek() to CompressingFileReader
* Thu Sep 19 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.160.gdad4bf3+git.1379598333.dad4bf3:
  + Handle X-Copy-From header in account_quota mw
  + Optimizations to Ring.get_more_nodes()
  + Refactor common/utils methods to common/ondisk
  + Add HTTPSeeOther(303) and HTTPTemporaryRedirect(307) to swob
* Wed Sep 18 2013 dmueller@suse.com
- fix requires
* Mon Sep 16 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.152.g8e48dd6+git.1379375476.8e48dd6:
  + remove useless if from slo
  + Remove unused method iter_devices_partition
  + Removed many unnecessary uses of dict.keys
  + Supply correct arguments to __init__ of a base class
* Sun Sep 15 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.144.g31f706b+git.1379203387.31f706b:
  + Add support for POST commit coverage runs
* Fri Sep 13 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.142.g0fe02a6+git.1379115468.0fe02a6:
  + Add handoffs_first and handoff_delete to obj-repl
  + Use an existing local var rather than doing alookup
  + Switched some relative imports to be absolute
  + Use a local variable auditor_worker
* Thu Sep 12 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.135.gcb114e5+git.1379029327.cb114e5:
  + Verbose functional test request failures.
  + Fix sync test when localhost on port 80 is binded
  + Tinker with dockstrings in back-ends and related places
  + fix race in test_wait on busy server
  + Ensure audit tests don't cause unwanted errors
* Wed Sep 11 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.125.gbfcf72a+git.1378942672.bfcf72a:
  + Assume ETag is always in the metadata
  + Split backends off swift/common/db.py
  + Remove keep_data_fp argument from DiskFile constructor
  + Improve unittest coverage of account reaper
  + Man page lintian errors and warnings
* Tue Sep 10 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.117.g21c322c+git.1378856477.21c322c:
  + [tempauth] update token if its value changes or expires
  + Remove dupe account_audit when reporting stats
  + Add Apache 2.0 licensing headers
  + fix swift i18n
* Mon Sep  9 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.109.gde4da07+git.1378770742.de4da07:
  + Fix unbalanced rings after initial creation.
  + Perform fewer stat calls when doing auditing of objects
  + Provide a method for retrieving on-disk metadata
  + Do not use locals() for string formatting (H501)
  + Use Python 3.x compatible except construct
  + Move string expansion outside localisation (H702)
  + Don't stat the path in ``unlink_older_than``
  + Fixed a suite that was over-indented
* Sun Sep  8 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.94.ge8bf111+git.1378599595.e8bf111:
  + Made the signature of HeaderKeyDict.__init__ match dict's
* Sat Sep  7 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.92.g8a255a3+git.1378537806.8a255a3:
  + Refactor finalize_put as an object method
  + Rename DiskFile.writer to create
  + Add a delete() method to DiskFile
  + Remove reference to 'file' built-in
* Thu Sep  5 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.86.gf1940bb+git.1378424486.f1940bb:
  + Pep8 container test_sync and test_diskfile (9 of 12)
  + Pep8 account and proxy server unit tests (10 of 12)
  + Rename param to avoid use of built-in name hash
  + Flake8 container test_server.py (11 of 12)
  + Pep8 final two unit test modules and enforce (12 of 12)
  + add reseller_admin_role to sample config
* Wed Sep  4 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.76.gdac2893+git.1378339183.dac2893:
  + Pep8 unit test modules w/ <= 10 violations (5 of 12)
  + Pep8 unit test modules w/ <= 20 violations (6 of 12)
  + Pep8 unit tests in middleware > 20 violations (7 of 12)
  + Pep8 remaining unit test modules in common (8 of 12)
* Tue Sep  3 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.68.gf2ca932+git.1378251795.f2ca932:
  + Only set PYTHON_EGG_CACHE if it isn't already set
  + Fix changes in XML that broke old clients
  + Fix string format error in DiskFile close
  + Always format messages sent to FakeLogger
  + Pep8 the functional tests (2 of 12)
  + Pep8 the functionalnosetests tests (3 of 12)
  + Pep8 unit test modules for hacking and one liners (4 of 12)
  + Made the HTTP comparisons slightly more idiomatic
* Tue Sep  3 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.52.g0b7432b+git.1378166683.0b7432b:
  + Pep8 the probe tests (1 of 12)
* Fri Aug 30 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.51.g4893aac+git.1377907173.4893aac:
  + Defer computation of available methods until needed.
  + Small test cleanups from b63089d.
  + Two small performance improvements to header generation
  + Allow users to extract tars to containers with ACLs set
* Fri Aug 30 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.45.g4f0e99c+git.1377877056.4f0e99c:
  + Refactor DiskFile init logic into multiple methods
* Fri Aug 30 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.43.g6bbe251+git.1377821665.6bbe251:
  + Add delay in swift-bench
  + get rid of unlinkold
  + remove unused reference to resellers_conf
  + Added test for timeout regression
  + Clean up some of the proxy unit tests.
  + Remove duplicate code for update_put_timestamp().
  + Clean up utf8ness quote
  + Add constructor args to swob.Request.blank
* Wed Aug 28 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.29.gc809a3e+git.1377733766.c809a3e:
  + Refactor how we pick listings' content type.
  + Fix setdefault() for swob's HeaderKeyDict.
  + Refactor path splitting and validation.
  + Don't use float() when normalize_timestamp() does it.
  + Fix regression that causes Timeouts to return 500
* Tue Aug 27 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.21.gbdba160+git.1377561723.bdba160:
  + Improve swift-bench performance
* Sat Aug 24 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.20.g621ea52+git.1377303431.621ea52:
  + Added container listing ratelimiting
  + use testCase.assert instead of assert and try...except
  + Run a more GC iterations to make sure weakrefs are collected
* Fri Aug 23 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.10.gb4c5d6b+git.1377216795.31cab64:
  + Fix range GET w/If-None-Match.
  + clean temp dir in /tmp
  + Make the length of a line logged configurable
  + Don't silence errors in spawning processes
  + change .data vrs .meta file metadata filtering in obj.diskfile
* Thu Aug 22 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2.2.gad54e31+git.1377130488.c9ee984:
  + fix gettext calls to operate on uninterpolated strings
  + Migrate to pbr for build
* Tue Aug 20 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2+git.1377043133.5c6f001:
  + Don't append %%interface with ipv6 ips.
  + Use randomly named file for temporay file
* Sat Aug 17 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2+git.1376782797.557bc32:
  + Unify DatabaseBroker.reclaim
* Fri Aug 16 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2+git.1376696358.5f4e7cd:
  + return the SLO etag generated from the segment etags on PUT
  + Staticweb shortcut object 404s
  + Implements configurable swift_owner_headers
  + DiskFile logger argument is not a keyword
  + Some how DELETE not using _parse_path()
* Thu Aug 15 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2+git.1376609717.a9dde1c:
  + Sped up tests by using smaller files
  + Add unit test for account/auditor.py
* Wed Aug 14 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2+git.1376523978.8a84998:
  + memcache timeout parameter bug in get_info
* Tue Aug 13 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2+git.1376438246.60cc7c0:
  + Removed monkeypatching of __del__ in tests
  + Rename loop var i in sub loop branch
* Tue Aug 13 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2+git.1376352763.c272241:
  + Always close HTTP connections in the container updater.
* Sat Aug 10 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2+git.1376135145.716ad3e:
  + added a couple of java libraries to associated projects
  + Add libcloud to associated_projects.
* Fri Aug  9 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2+git.1376007072.e8c847c:
  + Clarify staticweb configuration with keystone.
  + Ensure http_connect is mocked out in tests
  + Use /var/run/syslog on macosx for syslog tests.
  + Assignment to reserved built-in symbol
  + Add missing copyright license headers
* Thu Aug  8 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.2+git.1375921368.aebb258:
  + Fix handling of DELETE obj reqs with old timestamp
  + CHANGELOG and AUTHORS and .mailmap updates for 1.9.1
  + version bump to reflect current dev target
* Tue Aug  6 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1375832393.0e96911:
  + Increase test coverage of swift/common/db.py
* Mon Aug  5 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1375746046.3741fbe:
  + Fix sphinx error in swift.common.utils
  + Allow dispersion tools to use keystone server with insecure certificate
* Mon Aug  5 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1375735834.657a0e4:
  + Add swift-basicauth and better-staticweb to associated projects.
* Sat Aug  3 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1375574084.06402c0:
  + Correct misspell in comments
* Sat Aug  3 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1375488530.e10c8bf:
  + Remove duplicated code in direct_client.
  + Make pending_timeout an argument of __init__
* Thu Aug  1 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1375400950.1960332:
  + some container serialization cleanup
  + Fake http_connect in test_replicator test
  + give value [] if disallowed_metadata_keys is None
  + Just a tiny doc fix for a Sphinx warning
* Wed Jul 31 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1375313753.def2b85:
  + log return value before arguments when rsync error
  + Return name of header larger than MAX_HEADER_SIZE
  + add utf-8 charset to multipart-manifest=get resp
  + Tell swift to figure out content type
* Tue Jul 30 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1375227421.c5edf4c:
  + Set default wsgi workers to cpu_count
  + Add option to make probetests more brittle
  + Eliminate can_delete_db
  + Obscure the X-Auth-Token in proxy log
  + When iterating over a range of a file, always close it
  + fix(gitignore) : ignore *.egg and *.egg-info
* Tue Jul 30 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1375196501.6a9f55d:
  + Removed unnecessary monkeypatching of __builtin__
  + Encode unicode from JSON before using it as a string.
* Tue Jul 30 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1375142659.87ab2f6:
  + Allow floating point value for dispersion_coverage
  + Configuration options for error regex and log file in the config now
  + Fix incorrect status handling at staticweb
* Fri Jul 26 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1374882067.e155f6d:
  + Add bulk middleware to proxy-server.conf-sample
  + Unify _commit_puts for accounts and containers
* Thu Jul 25 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1374796457.76f12c8:
  + remove assert syntax
  + Tempurl md use of split_path in _get_account
  + Corrected many style violations in the tests.
  + Make sure users can't remove their account quotas
  + Catch swob responses that are raised.
  + fix name 'recon_container' to 'rcache'
  + Ignore coverage HTML directory and MANIFEST.
* Wed Jul 24 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1374709761.d1eeab9:
  + Make stale_reads_ok an argument of __init__
  + Unified format of boolean params in conf files
  + Fix bulk's unit tests on Mac OS.
* Wed Jul 24 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1374624566.3748b54:
  + Don't allow users to delete their own account.
  + Fix make_pre_authed_request function to not fail when path arg is None.
  + Fix the way possibly_quarantine reraises an exception
  + Accept valid Accept headers in swob.
  + Add 'Z' into isoformat for UTC time
  + Remove extra lstat() calls from check_mount
  + Move the mount checking into DiskFile constructor
  + Corrected a number of style violations in the tests.
  + Ensure that files are always closed explicitly.
  + fix unit tests in 2.6 by using closing(GzipFile)
  + Add notes for /srv/node in swift-object-info
* Tue Jul 23 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1374537682.3a339e9:
  + Ensure that files in tests are closed.
  + Remove unused exceptions
* Sat Jul 20 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1374333856.0fdad0d:
  + Refactor and add tests for db_replicator
  + Ensure that files are always closed in the tests.
  + Remove list comprehension where the result is unused.
  + Close SQLite cursors when creating functions.
* Fri Jul 19 2013 dmueller@suse.com
- fix filelist
* Fri Jul 19 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1374192271.c9de9f2:
  + Forklift the DiskFile interface into it's own module
* Wed Jul 17 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1374055116.167897b:
  + Move replication allow method to decorators
  + Fix unit tests to properly marked deleted files
  + Refactor auditors to rely on expected gen names
* Mon Jul 15 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1373932034.18a0813:
  + Start using Hacking
  + Add documentation about flake8+hacking.
* Sun Jul 14 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1373845304.cbc29e4:
  + Extract quorum-size calculation to utility method.
* Fri Jul 12 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1373672579.eb43021:
  + Make keystoneauth reseller_prefix check for _
  + make internal client metadata methods return dicts with lower case keys
* Tue Jul  9 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1373412898.72faf7b:
  + Revert "docfix apache2 now supports client chunked encodin"
* Tue Jul  9 2013 vuntz@suse.com
- Revert part of change in swift-proxy.init that broke the init
  script.
* Thu Jul  4 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1372924507.151313b:
  + Fix flaky test.
* Wed Jul  3 2013 speilicke@suse.com
- Wrong swift-proxy.init output
* Wed Jul  3 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1372840363.7bb1d07:
  + Record some simple object stats in the object auditor
* Tue Jul  2 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1372808099.bc35717:
  + small cleanup to associated projects page
* Tue Jul  2 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1372723892.a24c89e:
  + adding copyright notice
* Sun Jun 30 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1372550942.4a90414:
  + docfix apache2 now supports client chunked encodin
  + Update docs to use default XFS inode size
* Sat Jun 29 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1372464597.e759dad:
  + Add test for swift.common.utils.lock_file
* Fri Jun 28 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1372378049.c6e5372:
  + Make formpost work with multiple tempurl keys.
* Thu Jun 27 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1372291309.2a91768:
  + Adding unit tests for direct client
  + TempAuth: don't return 401/403 if .r without .rlistings
  + Change ring partition size for SAIO
  + Allow SLOs to be made up of other SLOs
* Wed Jun 26 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.1+git.1372257506.66a0817:
  + Local write affinity for object PUT requests.
  + updated changelog and authors update for 1.9.0 release
  + Deleted account respond as non existing accounts
  + version bump to 1.9.1
  + Remove dead code and tests for staticweb.
* Wed Jun 26 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.0+git.1372205145.83bdd0b:
  + Refactor DiskFile instantiation in object server.
  + Fix swift-dispersion-report.
  + Use object name from request in bulk Errors
  + Add sample rsyslog.conf.
* Tue Jun 25 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.0+git.1372118681.13347af:
  + Improve swift's keystoneauth ACL support
* Mon Jun 24 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.0+git.1372032221.054ffbe:
  + Stop getting useless bytes on manifest Range requests.
  + Clean up some remnants of StaticWeb's and TempURL's custom caching.
* Sat Jun 22 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.0+git.1371859335.75660a1:
  + python3: Introduce py33 to tox.ini
  + Add "normal", optparse-style options to swift-ring-builder add.
  + bulk response Content-Type does not match request Accept header
  + Added utils.FileLikeIter
  + use get_container_info for staticweb
  + Add example Apache config files
* Fri Jun 21 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.0+git.1371772897.ff02537:
  + Add max_header_size to swift.conf-sample and relative UT
  + update .gitignore
* Thu Jun 20 2013 iartarisi@suse.com
- Use openstack-config instead of sed to modify config files
* Thu Jun 20 2013 iartarisi@suse.cz
- Set SUSE openstack-swift user as default in config files (bnc#825710)
* Wed Jun 19 2013 opensuse-cloud@opensuse.org
- Update to version 1.9.0+git.1371686248.1b930dd:
  + Swift tests for unicode headers
  + Add branch coverage reporting
  + Optional TCP_KEEPIDLE in unit tests
  + Make TempURL more cache-efficient.
  + version bump to 1.9.0 to reflect current dev target
* Tue Jun 18 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1371598478.60c1bc5:
  + Treat directory objects as not found
* Mon Jun 17 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1371427504.f99cf2d:
  + Fixed some minor doc building errors
* Sat Jun 15 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1371254923.0d24b3e:
  + Fix ring validate with device prior to rebalance.
  + Fix 503 on account/container HEAD w/invalid format.
  + Remove Lucid/ppa instructions from SAIO guide
  + Better escaping for GET /v1/a?format=xml.
  + More xml fixes
* Fri Jun 14 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1371168351.7757144:
  + Add UT for checking special chars in object name
  + Fix formpost with queries without user_agent.
  + Improve SAIO deploy document.
  + Added logging of x-delete-at values
  + Checked user input in XML responses.
* Thu Jun 13 2013 dmueller@suse.com
- install and package dispersion.conf
* Thu Jun 13 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1371082005.1384171:
  + get_info - removes duplicate code (Take 3)
  + Fix functional tests with keystone.
* Wed Jun 12 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1371028895.5bfd2d7:
  + Use threadpools in the object server for performance.
  + Add parallelism to object expirer daemon.
  + Fixed Bug 1187200
  + Add non-slash delimiter tests
  + Local read affinity for GET/HEAD requests.
  + Tempauth - remove change made to HTTP_X_AUTH_TOKEN
* Tue Jun 11 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1370945682.24a2ca6:
  + Restore loadapp checking
  + Make sample configs more readable.
* Sat Jun  8 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1370735090.03c0c5d:
  + Improve config samples
* Fri Jun  7 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1370648677.157f616:
  + Remove <cond> and <val1> or <val2> systax
* Thu Jun  6 2013 dmueller@suse.com
- install sample config files by default
- put all config files in /etc/swift (all daemons
  run under the same user anyway, there is no point in
  spreading it out)
* Tue Jun  4 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1370389399.63a5a93:
  + Fix faked-out account GET for JSON and XML.
  + implement an rsync_bwlimit setting for object replicator
  + Change to use dash instead of slash
* Mon Jun  3 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1370302999.567b43e:
  + Add requirements files to the source distribution
* Fri May 31 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1370044014.ee5e3bb:
  + Rework to support RFC 2616 Sec 4.4 Message Length
  + Rename requires files to standard names.
  + Mock SysLogHandler for proxy/test_server.py
  + Replaced <exc>.message with str(<exc>)
* Thu May 30 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1369957564.5501a40:
  + Handle DB creation race condition
  + Move parameter checking before disk accesses
  + Subtle change to tempurl content-disposition names
  + In TempURL, cache "no keys" for a shorter time.
* Wed May 29 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1369871299.a2db3b6:
  + RingBuilder.add_dev returns device id
* Wed May 29 2013 dmueller@suse.com
- remove setBadness call from rpmlintrc
* Tue May 28 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1369784900.b147c9e:
  + Made tests use a JSON parser in liue of eval.
* Mon May 27 2013 dmueller@suse.com
- fix missing requires on test subpackage
* Sat May 25 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1369525487.1b283d4:
  + Retrieve the swift version with recon
* Fri May 24 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1369439153.43bf568:
  + Put some comments in places we get asked about a lot
  + Fixed probetests
  + Move parse search logic outside from builder
* Thu May 23 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1369352673.b4b35c2:
  + Fix problem with changing class attribute
* Wed May 22 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1369266390.dacdbe9:
  + close socket on exceptions
  + Fix ValueError from handoff logging.
  + account-reaper warns if not making progress
  + Hide the file descriptor and disk write methodology for PUTs
* Tue May 21 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1369180394.deb01b8:
  + Don't delete containers when they weren't created.
  + Fix two documentation warnings.
  + Add ability to save builder data to a disk file
  + Move common code into a separate function.
  + Set TZ environment variable to avoid a stat call
  + Add unit tests to ensure TZ variable remains set
* Sat May 18 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1368921252.69cf78b:
  + Moved tests for moved obj.base code
* Fri May 17 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1368834899.d754b59:
  + Moved some code out of swift.obj.replicator
  + Autocreate cleanups
* Fri May 17 2013 dmueller@suse.com
- adjust d2to1 dependency
* Fri May 17 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1368749098.7d765bb:
  + Remove dead code.
* Thu May 16 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1368710805.678a3ae:
  + Implementation of replication servers
  + Skip IPv6 addresses in cname_lookup middleware.
  + Metadata retrieving from sqlite must be str for key
* Wed May 15 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1368661461.5015724:
  + Refactor Bulk middleware to handle long running requests
  + Perform mount check after REST params valid on PUT
* Wed May 15 2013 dmueller@suse.com
- update buildrequires (pbr/d2to1)
* Wed May 15 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1368608418.884b7bb:
  + Enhance log msg to report referer and user-agent
  + Fix obscure double url bug in container quota middleware
* Sun May 12 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1368401900.7d625f6:
  + Allow 2 TempURL keys per account.
* Sat May 11 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1368315483.1abe5dd:
  + Doc changes for new pip-requirements
* Tue May  7 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1367969943.c3e6f3a:
  + Fixed issue with use of delimiter in container queries.
  + have tempurl allow OPTIONS requests
* Mon May  6 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1367832691.506a2b1:
  + Add an explicit unit test for handling content-length: 0
  + Fix rebalance for zero weighted devices.
  + conf.d support
  + Adds chunk_size to CompressingFileReader.
  + Skip cname_lookup when host is an IP address
* Mon May  6 2013 dmueller@suse.com
- add swift-config to the filelist
* Thu May  2 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1367537891.99891e0:
  + Update to flake8 instead of pep8.
  + Rename "file" to "disk_file"
* Wed May  1 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1367451519.d69fa43:
  + Uses None instead of mutable dicts for default function arguments
* Tue Apr 30 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1367365123.7bf0db6:
  + Container info memcache change broke ratelimiting.
  + Add the max_clients parameter to bound clients
  + Uses None instead of mutable lists for function param defaults
* Mon Apr 29 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1367279923.407e08f:
  + Make it easier to debug badly broken tests.
  + Improved autocreate testing
  + Included time inside trans_id
* Mon Apr 29 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1367222610.58259df:
  + Add crossdomain.xml middleware
  + Push fallocate() down into mkstemp(); use known size
* Sat Apr 27 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1367020840.1b9b989:
  + copy X-Delete-At unless X-Fresh-Metadata: true is supplied on an object copy
* Fri Apr 26 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1366970830.55c817c:
  + Fixing /etc/swift.conf-sample to include
  + Add auth_version to dispersion.conf.5
* Tue Apr 23 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1366754395.5d52d2d:
  + Made colons quote-safe in logs; mainly for ipv6
* Tue Apr 23 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1366675446.7f534fa:
  + fix dict duplicated key
* Mon Apr 22 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1366638629.f63dc07:
  + Change logger name to module itself instead of root
  + Add x-remove-versions-location for feature: disable versioning
  + Fix reading xattrs in object-server's unittests.
  + Fix container-server sorting for manifest listings.
  + SLO multipart-manifest=get returns incorrect Content-Type
  + Change setup.cfg style.
  + Update documentation for account_quota middleware
  + add unit tests for db_replicator
  + Allow a configurable set of TempURL methods
  + directory /var/cache/swift /srv/node should be created.
  + Allow all headers requested for CORS.
  + Bug in SLO with multipart-manifest=get content type.
  + Refactored lists of nodes to contact for requests
  + objects md5-collisions
  + Adding a new optional variable called trans_id_suffix
  + Account Quota Correction
  + Correcting output of swift-ring-builder
  + fix email address
  + fix probe tests to work in a VM using mount_check
  + Refactoring format_device function
  + slobjects can not be made of other slobjects
  + Expirer now quotes names when deleting
  + fix slo docs
  + Drop cache after fsync
  + Extra safety on account-level DELETE
* Tue Apr  2 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.1+git.1364897054.01a5a47:
  + additional unit test coverage for container/server.py
  + Fixing SLO range requests
  + fixed some minor things in tests that pyflakes complained about
  + fixes some problems pyflakes complains about
  + updated AUTHORS and CHANGELOG
  + Dynamic Large Object sleeps too much
* Sun Mar 24 2013 cloud-devel@suse.de
- Update to version 1.8.1+git.1364083378.a979c80:
  + Fix for unicode issues in staticweb
  + instruction command was not documented in right format.
  + Fix bugs in bulk and slo and small doc change.
  + Add support for Hash Prefix
* Thu Mar 21 2013 cloud-devel@suse.de
- Update to version 1.8.1+git.1363880673.7df4323:
  + Improved container-sync resiliency
  + Give friendly notification in swift-get-nodes
  + Permit functional tests against Swift with Keystone
  + Fix crash in swift-ring-builder's list_parts command.
  + Small clarification to swift-recon section of admin guide.
  + swift-ring-builder blows up when not supported command requested.
  + Basic ring builder validation.
  + Instruction for multi node setup misses /var/run/swift creation
  + increase unit test coverage on account server
  + AUTHORS/CHANGELOG uploades for the next release
  + version bump for 1.8.1
  + Use role in insensitive case in keystoneauth.
  + fix stupid bug with bulk delete max items
  + Fix misspelled variable.
  + Fix for attempted COPY of objects gt MAX_FILE_SIZE
* Sun Mar 17 2013 dmueller@suse.com
- Update to version 1.7.7+git.1363520288.c2f8f00:
  + Add tests and doc entry for request.environ[reseller_request]
  + Add missing CONTRIBUTING.md to source tarball
  + Add a region tier to Swift's ring.
  + Fix swift-ring-builder's list_parts command.
  + Remove check for valid Origin for the "actual request".
  + Fix format device
* Wed Mar 13 2013 cloud-devel@suse.de
- Update to version 1.7.7+git.1363132994.f6d1fa1:
  + Fixed bug with account_info
* Mon Mar 11 2013 dmueller@suse.com
- Start using obs-service-github_tarballs
* Mon Mar 11 2013 dmueller@suse.com
- Update to version 1.7.7+git.1363001105.5e427e5:
  + Account and container info fixes and improvement.
  + timing-based affinity sorting for primary replicas
  + Fixed formpost QUERY_STRING bugs.
  + Adding speed limit options for DB auditor
  + Allow acl with a valid token.
  + Add tests on keystone for invalid path requests.
  + Add cache=swift.cache for authtoken example.
  + Make rings' replica counts adjustable.
  + Improve bin/swift-account-audit
  + Correct docstring for swift.common.ring.utils.build_tier_tree and add
  + Fix descriptions in sample configs.
  + Add debug level logs for TempAuth.authorize.
  + Move the swift.1 manpage to python-swiftclient
  + Account Server: Refactor HEAD request handler
  + Force log entries to be one line
  + Adding a quick note to helper functions so its clear what they do and
  + Updating classifiers status to stable and clean up
  + make swift fsync
  + Added per disk PUT timing monitoring support.
  + Remove reduant check of list.
  + TempURL filename options; bug fixes
  + Static Large Object Support
  + Updated get_more_nodes algorithm
  + David Hadas email address has been changed.
  + Spread handoffs out better around zones.
  + Fix misspelled variable name
  + Support listing endpoints for an object.
  + Support tests for Apache
  + simplify the chexor function
  + Fix some unreadable code.
  + Account quotas
  + Add exception to swift-drive-audit if no date in line.
* Sun Feb 24 2013 cloud-devel@suse.de
- Update to version 1.7.7+git.1361729875.d1381ba:
  + Change in swift-drive-audit handling log rotation.
  + Adds first-byte latency timings for GET requests.
  + Documentation fixups
* Fri Feb 22 2013 saschpe@suse.de
- BuildRequire openstack-suse-macros instead of openstack-macros
* Mon Feb 18 2013 dmueller@suse.com
- Update to version 1.7.7+git.1361180780.e88ff34:
  + Make statsd sample rate behave better.
  + Fixed bug in domain_remap and cname_lookup middleware
  + Deprecate is_admin feature.
  + Allow change the endpoint_type when use swift-dispersion tools
  + Made internal client handle failed requests better
  + Change the flag set to specify bulk delete and expand archives from a HTTP
  + Fixed some swift-recon typos
  + minor development doc changes
  + Use a doubled proxy-logging instead of each middleware handling it
  + Add generated keystone documentation to misc.rst.
  + Replaces Copyright statements for LLC with Foundation, removes date.
  + Fix spelling mistakes
  + log message in exception level when path encoding errors happen.
  + Swift MemcacheRing (set) interface is incompatible fixes
  + fix large objects with unicode
  + Cleanup of file permissions
* Thu Feb  7 2013 saschpe@suse.de
- Update test configuration:
  + Use correct storage location
* Thu Feb  7 2013 saschpe@suse.de
- Update to version 1.7.7+git.1360236509.9f14161:
  + Fixes 'not in' operator usage
  + Basic container quotas
- Fetch test configuration from SUSE-Cloud github repository
* Mon Feb  4 2013 dmueller@suse.com
- Update to version 1.7.7+git.1359979321.ec084de:
  + Fix keystoneauth with OPTIONS headers (eg: CORS)
  + Add wsgify and split_path utilities to swob
  + Add optional locking to swift-ring-builder
  + Handle access_log_headers in proxy_logging
  + Added fallocate_reserve option
  + Allow rebalance to take a seed.
  + Remove tempauth allowed_sync_hosts conf option
  + Cleanup based on pyflakes.
  + Deterministic, repeatable serialization for rings.
  + Optimize the ring builder's _reassign_parts() method.
* Mon Jan 28 2013 dmueller@suse.com
- Update to version 1.7.7+git.1359365000.2f663ff:
  + Allow for multiple X-(Account|Container)-* headers.
  + Update auto-generated docs
  + Add more command-line options to swift-bench.
  + Add handler for CORS "actual requests"
  + Bulk Requests: auto extract archive and bulk delete middleware.
* Wed Jan 23 2013 cloud-devel@suse.de
- Update to version 1.7.7+git.1358959291.f2941b0:
  + Add --run-dir switch to swift-init
  + Fix superfluous GET requests in swift-bench.
  + prevent irregular auth_prefix config in tempauth
  + Validate numericness of ports in builder files.
* Mon Jan 21 2013 dmueller@suse.com
- Update to version 1.7.7+git.1358760990.6c5fc3c:
  + consistency and grammatical tweaks
  + Fix HEAD request response when request not given to response.
  + Fixed bug in object replicator
  + Add container-sync to container-server.conf doc.
  + Some optimizations for ring rebalancing.
  + Make object-auditor to use one logger
  + swob refactors needed for sos
  + get swob.Request.blank to parse path
  + authors and changelog update for swift 1.7.6
  + version bump to 1.7.7-dev
* Mon Jan 14 2013 saschpe@suse.de
- Update to version 1.7.6+git.1358173390.d904fd4:
  + Reject names with NULL characters
  + swift-recon: Added oldest and most recent repl
  + Fixed version req for netifaces to 0.5
  + Allow actual paths to work for swift-get-nodes
  + Check whether poll is available or not and let eventlet chose the best hub when it isn't.
  + Functional tests use x-auth-token rather than x-storage-token
  + Fix for subtle bug from 5c8f9c52e3f2944f01cea621326532e058a225f7
  + saio truncate instead of dd (for reals)
  + Revert "suggest fallocate instead of dd in saio"
  + Move InputProxy to utils
  + Fixes console logging with non-swift middleware
  + suggest fallocate instead of dd in saio
  + Convert LICENSE to use unix style line endings.
  + Refactor Ring::get_nodes() and Ring::get_part_nodes()
  + Made 507s report drive, if known.
  + Added override for swift-init's KILL_WAIT
  + one dot, 5%% increase in coverage
  + Fix permissions from last commit
  + document correct config in dispersion-report help
  + Add a license header to functionalnosetests
  + Fix needed for keystone middleware logging
  + Use install_requires in setup.py
  + Avoid infinite recursion in swift.obj.replicator.get_hashes.
  + Add config option to turn eventlet debug on/off
  + Add dispersion report flags to limit reports
  + Add config of server start timeouts for probetests
  + Allow dot test runners from any dir
  + capture resetswift output in probetests
  + Allow optional, temporary healthcheck failure.
  + Ignore pycscope files
  + drop_privileges should also set HOME
  + 406 if we can't satisfy Accept
  + bp/cross-tenant-acls: allow tenantId:user, tenantName:user, and *:user ALCs
  + Swob bugfixes; for ? in names specifically
  + Added --top option to swift-recon -d
  + Updates to use new keystoneclient middleware.
  + Fix bug with swob.Request.path_info_pop
  + added GoLang binding and CDMI to associated projects
  + Replace hard-coded test accounts with user-configured values
  + Upgrade pep8 to 1.3.3.
  + Improve container-sync docs.
  + Add CONTRIBUTING file.
  + pep8 middleware
  + pep8 db.py
  + pep8 direct client
  + pep8 utils.py
  + Fix for container sync not syncing last rowid
  + Remove IP-based container-sync ACLs from auth middlewares.
  + Fix lazy-listing of object segments.
  + Use a delta timeout for memcache where possible
  + Refactor http_connect() to use http_connect_raw()
  + Updating doc reflecting the move of auth_token.
  + Refactor db_replicator's roundrobin_datadirs
  + change catch_errors to use WSGIContext
  + Refactor DiskFile to hide temp file names and exts
  + check response status in WSGIContext._app_call
  + fix bug in deleting account memcache.
  + Remove outdated Debian packaging guide.
  + patch utils.HASH_PATH_SUFFIX in proxy unittests
  + Fix 500 on GET of many-segment manifest.
  + fix bug1039861, remove license header in doc/source/conf.py.
  + Better TempAuth storage URL guessing
  + fix error with setting max age and incorrect tests
  + Make swift-bench use less memory with large object sizes.
  + give swob default content-type
  + Make DELETE requests to expired objects return 404.
  + charset for default responses
  + use Host: for location rewrites
  + Fixed swift-bench when using -b and a conf file
  + Fixed bugs with internal client and object expirer
  + Use computed size on object PUT, not fstat.
  + 1.7.6 version bump
  + updated for 1.7.5 release
  + statsd timing refactor
  + add OPTIONS to proxy_logging configs and docs
  + Better RFC support for OPTIONS and CORS preflight requests
  + Set content-type on account/container head
  + Use pypi for python-swiftclient dependency.
  + Split swob.content_range_header() into two methods.
  + Remove dead code in swob.Response.__init__.
  + Allow object-expirer to delete the last version of an object
  + Make multipart/byteranges boundary always length 32.
  + Separate wsgi init from web-front-end activation
  + re-use headers_to_container_info on container GET
  + blueprint Multi-range support implementation
  + Handle down object servers in container-sync
  + dispersion report option to output missing parts
  + Fixed bugs re: make_pre_authed* and SCRIPT_NAME
  + changed TRUE_VALUES references to utils.config_true_value() call
  + Fix non standard 100-continue behaviour
  + Extended documentation for using custom loggers
  + Allow unsetting of X-Container-Sync-To header.
  + Db reclamation should remove empty suffix dirs
  + Added partition option to swift-get-nodes
  + fix config parsing in swift-bench -x
  + Remove double GET on range requests.
  + Adding CORS support
  + Remove utf-8 in metadata and http header names
  + Track unlinks of async_pendings.
  + Two MIME types sent during test
  + Add OpenStack trove classifier for PyPI
  + Fixes Ilegal chunk encoding by the test_client
  + path_qs for swob.Request
  + Remove replication prioritization
  + removed duplicate in AUTHORS file
  + Relax mount point name checking.
  + Make StatsD tests less flaky.
  + do not dump_recon_cache on limited obj replic
  + Fix version requirement for mock library.
  + Random pep8 fixes!
  + Honor sample_rate in StatsD logging.
  + fix bug with swob.Request accept property
  + fix empty body getter bug 1067923
  + fixed internal client things
  + Allows removal of ACLs
  + fix swob for make_pre_authed_request
  + Fixing alterations to sys.path
  + fix typing in swift/common.db, swift/container/server.db
  + remove configobj from deps
  + Fix two edge cases with Range: header
  + add support for custom log handlers
  + internal client unicode paths
  + cleanup double repeated response.headers['X-Timestamp'] = file.metadata['X-Timestamp'] in swift.obj.server.HEAD
  + close_swift_conn is a method of swift.proxy.controllers.base.Controller, not function
  + Warn when killing fails with EPERM
  + catch no such file in hash_suffix
  + Allow underscores in account/user in tempauth via encoding.
  + local WSGI Request and Response classes
  + allow replicator run_once to check specific devices/partitions
  + Fix errors with fdatasync on BSD platforms
  + base controller GETorHEAD refactor
  + updated with 1.7.5 version bump and changelog update
  + Fixed leak on 499s
  + Restore old SIGPIPE handler in a proxy server test.
  + Gracefully handle stdin flush failure on BSD
  + Only set TCP_KEEPIDLE where supported
  + 1.7.2. changelog and version bump to 1.7.3-dev
  + Fix bug where serialization_format is ignored
  + replace a value set with utils.TRUE_VALUES
  + Add README.md to the tarball.
  + builder.add_devs gets next id if not provided
  + new more helpful README
  + added disable_fallocate info to docs
  + added errno.EINVAL check to fallocate
  + Adds Error Handling to swift-drive-audit for missing or unreadable /var/log/kern.log
  + obj replicator speed up
  + container_info returns a dict
  + swift constraints are now settable via config
  + Fix pep8 issues
  + Fix pep8 issues
  + Breakout search_devs & add get_builder() for reuse
  + fix some format
  + fix some format issure
  + format some code according to pep8
  + Obj replicator cleans up files where part dirs should be.
  + Fix pep8 issues in test_memcached.py.
  + fix update_deleted directory creation. bug 1035274
  + 1.7.1 version bump
  + Fall back to UDP if /dev/log does not exist.
  + Can run swift-bench across multiple cores/servers.
- Updated requirements:+
  + Moved from base package to python-swift
* Wed Jan  9 2013 saschpe@suse.de
- Remove the hard requires on python-netifaces-0.6, swift seems to
  always use fixed revision requirements which seem to be bogus
* Mon Jan  7 2013 cloud-devel@suse.de
- Start using obs-service-github_tarballs
* Fri Dec  7 2012 saschpe@suse.de
- Don't use /var/log/subsys
* Wed Dec  5 2012 saschpe@suse.de
- Use @PARENT_TAG@ in _service file to automate versioning
* Mon Dec  3 2012 saschpe@suse.de
- Drop openstack-swift-create-man-stubs.py:
  + Install manpages from upstream tarball instead
  + Drop dependencies on Jinja2, Paste, PasteDeploy
- Fix test requires on python-openstack.nose_plugin
- Minor rpmlint issues fixed
* Mon Nov 19 2012 saschpe@suse.de
- Install /etc/swift/test.conf for .unitests
* Mon Nov 19 2012 saschpe@suse.de
- Add missing spaces to "Requires: python-Swift >= 1.1.2"
* Fri Nov 16 2012 saschpe@suse.de
- Add .*test files to test package
* Thu Nov 15 2012 saschpe@suse.de
- Use openstack-macros
* Tue Nov 13 2012 saschpe@suse.de
- Split out doc package into seperate spec file
- Update test sub-package requirements
* Mon Nov 12 2012 saschpe@suse.de
- Update to version 1.7.4 (Folsom):
  + See https://github.com/openstack/swift/commits/stable/folsom
- Dropped the following upstreamed patches:
  + dir-traversals-checks.patch
  + rsync_object_replication.patch
  + swift-memcache-no-pickle.patch
  + test_runners.patch
  + test_swift.patch
- Updated Requires based on tools/pip-requires
- /usr/bin/swift isn't provided anymore, use python-swiftclient therefor
- Added "reload" entries in init scripts:
  + openstack-swift-container-auditor.init
  + openstack-swift-proxy.init
* Thu Nov  8 2012 saschpe@suse.de
- Drop from_vcs build flag
* Wed Oct 31 2012 saschpe@suse.de
- Rename /usr/bin/swift to /usr/bin/swift.old, the binary is also
  provided by python-swiftclient
* Tue Oct  9 2012 vuntz@suse.com
- Require python-netifaces
* Mon Sep 10 2012 vuntz@suse.com
- Add swift-memcache-no-pickle.patch: do not use pickle
  serialization for memcache, but JSON. Fix bnc#779215,
  CVE-2012-4406.
* Mon Jul 23 2012 bwiedemann@suse.com
- use shorter swift-container names to make startproc work
  with kernel's 15-char shortnames (bnc#772585)
* Mon Jul 16 2012 vuntz@suse.com
- Add dir-traversals-checks.patch: add checks to ensure no
  directory traversal can happen. See lp#1005908.
* Thu Jun 28 2012 saschpe@suse.de
- Split out python-swift package which includes everthing in
  %%{python-sitelib}
* Wed Jun 27 2012 saschpe@suse.de
- Consistent package summaries
- Macro cleanup:
  + Package is noarch except for SLE-11
  + No need to redefine %%_initddir, SLE-11 works correctly
* Wed Jun 27 2012 saschpe@suse.de
- Don't use intersphinx for documentation build (avoid internet access)
- Change versioning scheme to $release+git.$AUTHORDATE.$COMMITREV
- Simplify from_vcs macros
* Tue Jun 26 2012 iartarisi@suse.cz
- Add rsync patch to fix object replication for rsync 3.0.4 (lp#987388)
* Mon Jun 18 2012 saschpe@suse.de
- Better run %%restart_on_update in %%postun
- No need for %%py_requires (we also have an explicit "BuildRequires: python >= 2.6.8")
- Add rpmlintrc
* Mon Jun 18 2012 iartarisi@suse.cz
- Also set default user to 'openstack-swift' in proxy test config
* Mon Jun 18 2012 saschpe@suse.de
- Also set default user to 'openstack-swift' in test configuration files
* Tue Jun 12 2012 saschpe@suse.de
- Use 'openstack-swift' system user instead of 'swift'
- Use %%{_localstatedir}/lib instead of %%{_sharedstatedir} (equals '/usr/com')
  as the system user home directory
* Thu May 24 2012 jfehlig@suse.com
- Add 'Requires: python >= 2.6.8'
* Wed Feb  8 2012 rhafer@suse.de
- Fixed try-restart command in swift-proxy init script to only
  restart if the service was running before
- Don't enable services automatically during install
* Fri Jan 27 2012 mvidner@suse.com
- Updated to a current git snapshot.
* Mon Jan 16 2012 prusnak@opensuse.org
- fix initscript scriptlets
* Tue Jan 10 2012 bwiedemann@suse.com
- use spdx.org License name Apache-2.0
* Tue Dec 13 2011 vuntz@opensuse.org
- Merge changes to enable build from git:
  + Add from_vcs and no_from_vcs bconds, that can be used in
    addition to the BUILD_FROM_VCS macro to decide what to build.
  + Add some warning to summary of packages is building from VCS.
  + Package files that are new in git.
* Mon Dec  5 2011 prusnak@opensuse.org
- spec cleanup
- added rc symlinks for init scripts
* Fri Sep 23 2011 bwiedemann@suse.com
- Upgrade to 1.4.3 (Diablo)
* Wed Jun  1 2011 berendt@b1-systems.de
- update to bzr rev 304
- fixed Source0
- fixed version
* Thu May 19 2011 berendt@b1-systems.de
- update to bzr rev 295
* Thu Apr 21 2011 berendt@b1-systems.de
- update to bzr rev 286
  - only latest async pending is now sent
  - added the Accept-Ranges header to GET and HEAD requests.
  - Fix for Object replicator breaks when running object replicator with no objects on the server
  - Allow for double quarantining of dbs.  Just appends a uuid if there's naming conflict.
  - allowed_headers are returned from a GET but not HEAD
* Tue Apr 19 2011 berendt@b1-systems.de
- update to bzr rev 281
  - start of diablo release
  - Move loadapp to after-fork
  - swift-bench to clean up containers after it's done.
  - Update get_hashes in objrep to use utils.write_pickle
  - Remove ECONNRESET patch from proxy server
  - swauth-cleanup-tokens now handles 404s on token containers and tokens better
  - made client ip fill in, in the absence of a load balancer in the client field in the access logs.
  - Adding unit and probe tests for proxy timeout bug.
  - Adds param-signed URLs to swift3 middleware.
  - swauth scripts now exit with proper exit codes
  - stats collate_worker catchall
* Fri Apr 15 2011 berendt@b1-systems.de
- update to bzr rev 267
  - Final Cactus versioning.
- updated version to 1.3.0
* Tue Apr 12 2011 berendt@b1-systems.de
- update to bzr rev 265
* Wed Mar 16 2011 berendt@b1-systems.de
- update to bzr rev 248
  - fixed pattern matching/globbing in swift-log-uploader
  - Fixed an import that was causing Connection to not retry on
    HTTPExceptions
  - s3api: add get acl object and bucket support
  - s3api: fix PUT Object Copy
  - Fixes problem with creating a new processed files list in log
    processing when the download of that file fails
  - Removed DevAuth
- removed all devauth stuff in the spec file and used scripts/files
- cleanup of spec file
* Fri Mar 11 2011 berendt@b1-systems.de
- update to bzr rev 239
  - Fixes to work with WebOb 1.0.1 and WebOb 1.0.3
* Thu Mar 10 2011 berendt@b1-systems.de
- update to bzr rev 238
  - Skip the swift3 middleware tests if boto is not installed
  - Refactor proxy for concurrency and code reuse
  - a lot of internal code changes
* Thu Mar  3 2011 berendt@b1-systems.de
- update to bzr rev 229
  - ratelimiting does now handle memcache restart
  - lower memcached error limit duration
  - fixed edge case when log processor cannot get a log file for
    processing
  - s3api: use boto to get canonical string for signature
* Wed Feb 23 2011 seife+obs@b1-systems.com
- start tracking 1.3-dev bzr revisions again
- update to bzr rev 224
  - lots of changes and fixes, please see ChangeLog
* Thu Feb  3 2011 seife+obs@b1-systems.com
- fix file not found error in init script functions
* Thu Feb  3 2011 seife+obs@b1-systems.com
- official bexar release
  - rename to version 1.2.0
* Thu Feb  3 2011 seife+obs@b1-systems.com
- update to bzr rev 208 (real release candidate)
* Wed Feb  2 2011 seife+obs@b1-systems.com
- update to 1.2-rc (bzr rev 206)
- add dependency on memcached
- fix error in init scripts
* Tue Feb  1 2011 seife+obs@b1-systems.com
- 1.2-gamma-bzr204 is not yet 1.2.0, so keep the version number
  lower than 1.2.0. Otherwise later updates to 1.2.0 won't work
- update to bzr 204 (only cosmetic changes)
* Tue Feb  1 2011 berendt@b1-systems.de
- fixed version parameter to 1.2.0
* Fri Jan 28 2011 seife+obs@b1-systems.com
- update to bzr version 202
* Thu Jan 27 2011 seife+obs@b1-systems.com
- udated to current swift snapshot swift-1.2.0+bzr199
* Mon Nov 29 2010 seife+obs@b1-systems.com
- initial package, based on the fedora14 package, adapted to the
  openSUSE conventions and rules
